# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SageMaker'
prefix = 'sagemaker'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddAssociation = Action('AddAssociation')
AddTags = Action('AddTags')
AssociateTrialComponent = Action('AssociateTrialComponent')
BatchGetMetrics = Action('BatchGetMetrics')
BatchPutMetrics = Action('BatchPutMetrics')
CreateAction = Action('CreateAction')
CreateAlgorithm = Action('CreateAlgorithm')
CreateApp = Action('CreateApp')
CreateAppImageConfig = Action('CreateAppImageConfig')
CreateArtifact = Action('CreateArtifact')
CreateAutoMLJob = Action('CreateAutoMLJob')
CreateCodeRepository = Action('CreateCodeRepository')
CreateCompilationJob = Action('CreateCompilationJob')
CreateContext = Action('CreateContext')
CreateDataQualityJobDefinition = Action('CreateDataQualityJobDefinition')
CreateDeviceFleet = Action('CreateDeviceFleet')
CreateDomain = Action('CreateDomain')
CreateEdgePackagingJob = Action('CreateEdgePackagingJob')
CreateEndpoint = Action('CreateEndpoint')
CreateEndpointConfig = Action('CreateEndpointConfig')
CreateExperiment = Action('CreateExperiment')
CreateFeatureGroup = Action('CreateFeatureGroup')
CreateFlowDefinition = Action('CreateFlowDefinition')
CreateHumanTaskUi = Action('CreateHumanTaskUi')
CreateHyperParameterTuningJob = Action('CreateHyperParameterTuningJob')
CreateImage = Action('CreateImage')
CreateImageVersion = Action('CreateImageVersion')
CreateLabelingJob = Action('CreateLabelingJob')
CreateModel = Action('CreateModel')
CreateModelBiasJobDefinition = Action('CreateModelBiasJobDefinition')
CreateModelExplainabilityJobDefinition = \
    Action('CreateModelExplainabilityJobDefinition')
CreateModelPackage = Action('CreateModelPackage')
CreateModelPackageGroup = Action('CreateModelPackageGroup')
CreateModelQualityJobDefinition = \
    Action('CreateModelQualityJobDefinition')
CreateMonitoringSchedule = Action('CreateMonitoringSchedule')
CreateNotebookInstance = Action('CreateNotebookInstance')
CreateNotebookInstanceLifecycleConfig = \
    Action('CreateNotebookInstanceLifecycleConfig')
CreatePipeline = Action('CreatePipeline')
CreatePresignedDomainUrl = Action('CreatePresignedDomainUrl')
CreatePresignedNotebookInstanceUrl = \
    Action('CreatePresignedNotebookInstanceUrl')
CreateProcessingJob = Action('CreateProcessingJob')
CreateProject = Action('CreateProject')
CreateTrainingJob = Action('CreateTrainingJob')
CreateTransformJob = Action('CreateTransformJob')
CreateTrial = Action('CreateTrial')
CreateTrialComponent = Action('CreateTrialComponent')
CreateUserProfile = Action('CreateUserProfile')
CreateWorkforce = Action('CreateWorkforce')
CreateWorkteam = Action('CreateWorkteam')
DeleteAction = Action('DeleteAction')
DeleteAlgorithm = Action('DeleteAlgorithm')
DeleteApp = Action('DeleteApp')
DeleteAppImageConfig = Action('DeleteAppImageConfig')
DeleteArtifact = Action('DeleteArtifact')
DeleteAssociation = Action('DeleteAssociation')
DeleteCodeRepository = Action('DeleteCodeRepository')
DeleteContext = Action('DeleteContext')
DeleteDataQualityJobDefinition = Action('DeleteDataQualityJobDefinition')
DeleteDeviceFleet = Action('DeleteDeviceFleet')
DeleteDomain = Action('DeleteDomain')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteEndpointConfig = Action('DeleteEndpointConfig')
DeleteExperiment = Action('DeleteExperiment')
DeleteFeatureGroup = Action('DeleteFeatureGroup')
DeleteFlowDefinition = Action('DeleteFlowDefinition')
DeleteHumanLoop = Action('DeleteHumanLoop')
DeleteImage = Action('DeleteImage')
DeleteImageVersion = Action('DeleteImageVersion')
DeleteModel = Action('DeleteModel')
DeleteModelBiasJobDefinition = Action('DeleteModelBiasJobDefinition')
DeleteModelExplainabilityJobDefinition = \
    Action('DeleteModelExplainabilityJobDefinition')
DeleteModelPackage = Action('DeleteModelPackage')
DeleteModelPackageGroup = Action('DeleteModelPackageGroup')
DeleteModelPackageGroupPolicy = Action('DeleteModelPackageGroupPolicy')
DeleteModelQualityJobDefinition = \
    Action('DeleteModelQualityJobDefinition')
DeleteMonitoringSchedule = Action('DeleteMonitoringSchedule')
DeleteNotebookInstance = Action('DeleteNotebookInstance')
DeleteNotebookInstanceLifecycleConfig = \
    Action('DeleteNotebookInstanceLifecycleConfig')
DeletePipeline = Action('DeletePipeline')
DeleteProject = Action('DeleteProject')
DeleteRecord = Action('DeleteRecord')
DeleteTags = Action('DeleteTags')
DeleteTrial = Action('DeleteTrial')
DeleteTrialComponent = Action('DeleteTrialComponent')
DeleteUserProfile = Action('DeleteUserProfile')
DeleteWorkforce = Action('DeleteWorkforce')
DeleteWorkteam = Action('DeleteWorkteam')
DeregisterDevices = Action('DeregisterDevices')
DescribeAction = Action('DescribeAction')
DescribeAlgorithm = Action('DescribeAlgorithm')
DescribeApp = Action('DescribeApp')
DescribeAppImageConfig = Action('DescribeAppImageConfig')
DescribeArtifact = Action('DescribeArtifact')
DescribeAutoMLJob = Action('DescribeAutoMLJob')
DescribeCodeRepository = Action('DescribeCodeRepository')
DescribeCompilationJob = Action('DescribeCompilationJob')
DescribeContext = Action('DescribeContext')
DescribeDataQualityJobDefinition = \
    Action('DescribeDataQualityJobDefinition')
DescribeDevice = Action('DescribeDevice')
DescribeDeviceFleet = Action('DescribeDeviceFleet')
DescribeDomain = Action('DescribeDomain')
DescribeEdgePackagingJob = Action('DescribeEdgePackagingJob')
DescribeEndpoint = Action('DescribeEndpoint')
DescribeEndpointConfig = Action('DescribeEndpointConfig')
DescribeExperiment = Action('DescribeExperiment')
DescribeFeatureGroup = Action('DescribeFeatureGroup')
DescribeFlowDefinition = Action('DescribeFlowDefinition')
DescribeHumanLoop = Action('DescribeHumanLoop')
DescribeHumanTaskUi = Action('DescribeHumanTaskUi')
DescribeHyperParameterTuningJob = \
    Action('DescribeHyperParameterTuningJob')
DescribeImage = Action('DescribeImage')
DescribeImageVersion = Action('DescribeImageVersion')
DescribeLabelingJob = Action('DescribeLabelingJob')
DescribeModel = Action('DescribeModel')
DescribeModelBiasJobDefinition = Action('DescribeModelBiasJobDefinition')
DescribeModelExplainabilityJobDefinition = \
    Action('DescribeModelExplainabilityJobDefinition')
DescribeModelPackage = Action('DescribeModelPackage')
DescribeModelPackageGroup = Action('DescribeModelPackageGroup')
DescribeModelQualityJobDefinition = \
    Action('DescribeModelQualityJobDefinition')
DescribeMonitoringSchedule = Action('DescribeMonitoringSchedule')
DescribeNotebookInstance = Action('DescribeNotebookInstance')
DescribeNotebookInstanceLifecycleConfig = \
    Action('DescribeNotebookInstanceLifecycleConfig')
DescribePipeline = Action('DescribePipeline')
DescribePipelineDefinitionForExecution = \
    Action('DescribePipelineDefinitionForExecution')
DescribePipelineExecution = Action('DescribePipelineExecution')
DescribeProcessingJob = Action('DescribeProcessingJob')
DescribeProject = Action('DescribeProject')
DescribeSubscribedWorkteam = Action('DescribeSubscribedWorkteam')
DescribeTrainingJob = Action('DescribeTrainingJob')
DescribeTransformJob = Action('DescribeTransformJob')
DescribeTrial = Action('DescribeTrial')
DescribeTrialComponent = Action('DescribeTrialComponent')
DescribeUserProfile = Action('DescribeUserProfile')
DescribeWorkforce = Action('DescribeWorkforce')
DescribeWorkteam = Action('DescribeWorkteam')
DisableSagemakerServicecatalogPortfolio = \
    Action('DisableSagemakerServicecatalogPortfolio')
DisassociateTrialComponent = Action('DisassociateTrialComponent')
EnableSagemakerServicecatalogPortfolio = \
    Action('EnableSagemakerServicecatalogPortfolio')
GetDeviceFleetReport = Action('GetDeviceFleetReport')
GetDeviceRegistration = Action('GetDeviceRegistration')
GetModelPackageGroupPolicy = Action('GetModelPackageGroupPolicy')
GetRecord = Action('GetRecord')
GetSagemakerServicecatalogPortfolioStatus = \
    Action('GetSagemakerServicecatalogPortfolioStatus')
GetSearchSuggestions = Action('GetSearchSuggestions')
InvokeEndpoint = Action('InvokeEndpoint')
ListActions = Action('ListActions')
ListAlgorithms = Action('ListAlgorithms')
ListAppImageConfigs = Action('ListAppImageConfigs')
ListApps = Action('ListApps')
ListArtifacts = Action('ListArtifacts')
ListAssociations = Action('ListAssociations')
ListAutoMLJobs = Action('ListAutoMLJobs')
ListCandidatesForAutoMLJob = Action('ListCandidatesForAutoMLJob')
ListCodeRepositories = Action('ListCodeRepositories')
ListCompilationJobs = Action('ListCompilationJobs')
ListContexts = Action('ListContexts')
ListDataQualityJobDefinitions = Action('ListDataQualityJobDefinitions')
ListDeviceFleets = Action('ListDeviceFleets')
ListDevices = Action('ListDevices')
ListDomains = Action('ListDomains')
ListEdgePackagingJobs = Action('ListEdgePackagingJobs')
ListEndpointConfigs = Action('ListEndpointConfigs')
ListEndpoints = Action('ListEndpoints')
ListExperiments = Action('ListExperiments')
ListFeatureGroups = Action('ListFeatureGroups')
ListFlowDefinitions = Action('ListFlowDefinitions')
ListHumanLoops = Action('ListHumanLoops')
ListHumanTaskUis = Action('ListHumanTaskUis')
ListHyperParameterTuningJobs = Action('ListHyperParameterTuningJobs')
ListImageVersions = Action('ListImageVersions')
ListImages = Action('ListImages')
ListLabelingJobs = Action('ListLabelingJobs')
ListLabelingJobsForWorkteam = Action('ListLabelingJobsForWorkteam')
ListModelBiasJobDefinitions = Action('ListModelBiasJobDefinitions')
ListModelExplainabilityJobDefinitions = \
    Action('ListModelExplainabilityJobDefinitions')
ListModelPackageGroups = Action('ListModelPackageGroups')
ListModelPackages = Action('ListModelPackages')
ListModelQualityJobDefinitions = Action('ListModelQualityJobDefinitions')
ListModels = Action('ListModels')
ListMonitoringExecutions = Action('ListMonitoringExecutions')
ListMonitoringSchedules = Action('ListMonitoringSchedules')
ListNotebookInstanceLifecycleConfigs = \
    Action('ListNotebookInstanceLifecycleConfigs')
ListNotebookInstances = Action('ListNotebookInstances')
ListPipelineExecutionSteps = Action('ListPipelineExecutionSteps')
ListPipelineExecutions = Action('ListPipelineExecutions')
ListPipelineParametersForExecution = \
    Action('ListPipelineParametersForExecution')
ListPipelines = Action('ListPipelines')
ListProcessingJobs = Action('ListProcessingJobs')
ListProjects = Action('ListProjects')
ListSubscribedWorkteams = Action('ListSubscribedWorkteams')
ListTags = Action('ListTags')
ListTrainingJobs = Action('ListTrainingJobs')
ListTrainingJobsForHyperParameterTuningJob = \
    Action('ListTrainingJobsForHyperParameterTuningJob')
ListTransformJobs = Action('ListTransformJobs')
ListTrialComponents = Action('ListTrialComponents')
ListTrials = Action('ListTrials')
ListUserProfiles = Action('ListUserProfiles')
ListWorkforces = Action('ListWorkforces')
ListWorkteams = Action('ListWorkteams')
PutModelPackageGroupPolicy = Action('PutModelPackageGroupPolicy')
PutRecord = Action('PutRecord')
RegisterDevices = Action('RegisterDevices')
RenderUiTemplate = Action('RenderUiTemplate')
Search = Action('Search')
SendHeartbeat = Action('SendHeartbeat')
StartHumanLoop = Action('StartHumanLoop')
StartMonitoringSchedule = Action('StartMonitoringSchedule')
StartNotebookInstance = Action('StartNotebookInstance')
StartPipelineExecution = Action('StartPipelineExecution')
StopAutoMLJob = Action('StopAutoMLJob')
StopCompilationJob = Action('StopCompilationJob')
StopEdgePackagingJob = Action('StopEdgePackagingJob')
StopHumanLoop = Action('StopHumanLoop')
StopHyperParameterTuningJob = Action('StopHyperParameterTuningJob')
StopLabelingJob = Action('StopLabelingJob')
StopMonitoringSchedule = Action('StopMonitoringSchedule')
StopNotebookInstance = Action('StopNotebookInstance')
StopPipelineExecution = Action('StopPipelineExecution')
StopProcessingJob = Action('StopProcessingJob')
StopTrainingJob = Action('StopTrainingJob')
StopTransformJob = Action('StopTransformJob')
UpdateAction = Action('UpdateAction')
UpdateAppImageConfig = Action('UpdateAppImageConfig')
UpdateArtifact = Action('UpdateArtifact')
UpdateCodeRepository = Action('UpdateCodeRepository')
UpdateContext = Action('UpdateContext')
UpdateDeviceFleet = Action('UpdateDeviceFleet')
UpdateDevices = Action('UpdateDevices')
UpdateDomain = Action('UpdateDomain')
UpdateEndpoint = Action('UpdateEndpoint')
UpdateEndpointWeightsAndCapacities = \
    Action('UpdateEndpointWeightsAndCapacities')
UpdateExperiment = Action('UpdateExperiment')
UpdateImage = Action('UpdateImage')
UpdateModelPackage = Action('UpdateModelPackage')
UpdateMonitoringSchedule = Action('UpdateMonitoringSchedule')
UpdateNotebookInstance = Action('UpdateNotebookInstance')
UpdateNotebookInstanceLifecycleConfig = \
    Action('UpdateNotebookInstanceLifecycleConfig')
UpdatePipeline = Action('UpdatePipeline')
UpdatePipelineExecution = Action('UpdatePipelineExecution')
UpdateTrainingJob = Action('UpdateTrainingJob')
UpdateTrial = Action('UpdateTrial')
UpdateTrialComponent = Action('UpdateTrialComponent')
UpdateUserProfile = Action('UpdateUserProfile')
UpdateWorkforce = Action('UpdateWorkforce')
UpdateWorkteam = Action('UpdateWorkteam')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Elastic Container Registry Public'
prefix = 'ecr-public'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchCheckLayerAvailability = Action('BatchCheckLayerAvailability')
BatchDeleteImage = Action('BatchDeleteImage')
CompleteLayerUpload = Action('CompleteLayerUpload')
CreateRepository = Action('CreateRepository')
DeleteRepository = Action('DeleteRepository')
DeleteRepositoryPolicy = Action('DeleteRepositoryPolicy')
DescribeImageTags = Action('DescribeImageTags')
DescribeImages = Action('DescribeImages')
DescribeRegistries = Action('DescribeRegistries')
DescribeRepositories = Action('DescribeRepositories')
GetAuthorizationToken = Action('GetAuthorizationToken')
GetRegistryCatalogData = Action('GetRegistryCatalogData')
GetRepositoryCatalogData = Action('GetRepositoryCatalogData')
GetRepositoryPolicy = Action('GetRepositoryPolicy')
InitiateLayerUpload = Action('InitiateLayerUpload')
PutImage = Action('PutImage')
PutRegistryCatalogData = Action('PutRegistryCatalogData')
PutRepositoryCatalogData = Action('PutRepositoryCatalogData')
SetRepositoryPolicy = Action('SetRepositoryPolicy')
UploadLayerPart = Action('UploadLayerPart')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS DeepComposer'
prefix = 'deepcomposer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateCoupon = Action('AssociateCoupon')
CreateAudio = Action('CreateAudio')
CreateComposition = Action('CreateComposition')
CreateModel = Action('CreateModel')
DeleteComposition = Action('DeleteComposition')
DeleteModel = Action('DeleteModel')
GetComposition = Action('GetComposition')
GetModel = Action('GetModel')
GetSampleModel = Action('GetSampleModel')
ListCompositions = Action('ListCompositions')
ListModels = Action('ListModels')
ListSampleModels = Action('ListSampleModels')
ListTagsForResource = Action('ListTagsForResource')
ListTrainingTopics = Action('ListTrainingTopics')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateComposition = Action('UpdateComposition')
UpdateModel = Action('UpdateModel')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CodeGuru Profiler'
prefix = 'codeguru-profiler'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddNotificationChannels = Action('AddNotificationChannels')
BatchGetFrameMetricData = Action('BatchGetFrameMetricData')
ConfigureAgent = Action('ConfigureAgent')
CreateProfilingGroup = Action('CreateProfilingGroup')
DeleteProfilingGroup = Action('DeleteProfilingGroup')
DescribeProfilingGroup = Action('DescribeProfilingGroup')
GetFindingsReportAccountSummary = \
    Action('GetFindingsReportAccountSummary')
GetNotificationConfiguration = Action('GetNotificationConfiguration')
GetPolicy = Action('GetPolicy')
GetProfile = Action('GetProfile')
GetRecommendations = Action('GetRecommendations')
ListFindingsReports = Action('ListFindingsReports')
ListProfileTimes = Action('ListProfileTimes')
ListProfilingGroups = Action('ListProfilingGroups')
ListTagsForResource = Action('ListTagsForResource')
PostAgentProfile = Action('PostAgentProfile')
PutPermission = Action('PutPermission')
RemoveNotificationChannel = Action('RemoveNotificationChannel')
RemovePermission = Action('RemovePermission')
SubmitFeedback = Action('SubmitFeedback')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateProfilingGroup = Action('UpdateProfilingGroup')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS SSO Directory'
prefix = 'sso-directory'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddMemberToGroup = Action('AddMemberToGroup')
CompleteVirtualMfaDeviceRegistration = \
    Action('CompleteVirtualMfaDeviceRegistration')
CompleteWebAuthnDeviceRegistration = \
    Action('CompleteWebAuthnDeviceRegistration')
CreateAlias = Action('CreateAlias')
CreateBearerToken = Action('CreateBearerToken')
CreateExternalIdPConfigurationForDirectory = \
    Action('CreateExternalIdPConfigurationForDirectory')
CreateGroup = Action('CreateGroup')
CreateProvisioningTenant = Action('CreateProvisioningTenant')
CreateUser = Action('CreateUser')
DeleteBearerToken = Action('DeleteBearerToken')
DeleteExternalIdPCertificate = Action('DeleteExternalIdPCertificate')
DeleteExternalIdPConfigurationForDirectory = \
    Action('DeleteExternalIdPConfigurationForDirectory')
DeleteGroup = Action('DeleteGroup')
DeleteMfaDeviceForUser = Action('DeleteMfaDeviceForUser')
DeleteProvisioningTenant = Action('DeleteProvisioningTenant')
DeleteUser = Action('DeleteUser')
DescribeDirectory = Action('DescribeDirectory')
DescribeGroup = Action('DescribeGroup')
DescribeGroups = Action('DescribeGroups')
DescribeProvisioningTenant = Action('DescribeProvisioningTenant')
DescribeUser = Action('DescribeUser')
DescribeUserByUniqueAttribute = Action('DescribeUserByUniqueAttribute')
DescribeUsers = Action('DescribeUsers')
DisableExternalIdPConfigurationForDirectory = \
    Action('DisableExternalIdPConfigurationForDirectory')
DisableUser = Action('DisableUser')
EnableExternalIdPConfigurationForDirectory = \
    Action('EnableExternalIdPConfigurationForDirectory')
EnableUser = Action('EnableUser')
GetAWSSPConfigurationForDirectory = \
    Action('GetAWSSPConfigurationForDirectory')
GetUserPoolInfo = Action('GetUserPoolInfo')
ImportExternalIdPCertificate = Action('ImportExternalIdPCertificate')
IsMemberInGroup = Action('IsMemberInGroup')
ListBearerTokens = Action('ListBearerTokens')
ListExternalIdPCertificates = Action('ListExternalIdPCertificates')
ListExternalIdPConfigurationsForDirectory = \
    Action('ListExternalIdPConfigurationsForDirectory')
ListGroupsForMember = Action('ListGroupsForMember')
ListGroupsForUser = Action('ListGroupsForUser')
ListMembersInGroup = Action('ListMembersInGroup')
ListMfaDevicesForUser = Action('ListMfaDevicesForUser')
ListProvisioningTenants = Action('ListProvisioningTenants')
RemoveMemberFromGroup = Action('RemoveMemberFromGroup')
SearchGroups = Action('SearchGroups')
SearchUsers = Action('SearchUsers')
StartVirtualMfaDeviceRegistration = \
    Action('StartVirtualMfaDeviceRegistration')
StartWebAuthnDeviceRegistration = \
    Action('StartWebAuthnDeviceRegistration')
UpdateExternalIdPConfigurationForDirectory = \
    Action('UpdateExternalIdPConfigurationForDirectory')
UpdateGroup = Action('UpdateGroup')
UpdateGroupDisplayName = Action('UpdateGroupDisplayName')
UpdateMfaDeviceForUser = Action('UpdateMfaDeviceForUser')
UpdatePassword = Action('UpdatePassword')
UpdateUser = Action('UpdateUser')
UpdateUserName = Action('UpdateUserName')
VerifyEmail = Action('VerifyEmail')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Elemental MediaLive'
prefix = 'medialive'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptInputDeviceTransfer = Action('AcceptInputDeviceTransfer')
BatchDelete = Action('BatchDelete')
BatchStart = Action('BatchStart')
BatchStop = Action('BatchStop')
BatchUpdateSchedule = Action('BatchUpdateSchedule')
CancelInputDeviceTransfer = Action('CancelInputDeviceTransfer')
CreateChannel = Action('CreateChannel')
CreateInput = Action('CreateInput')
CreateInputSecurityGroup = Action('CreateInputSecurityGroup')
CreateMultiplex = Action('CreateMultiplex')
CreateMultiplexProgram = Action('CreateMultiplexProgram')
CreateTags = Action('CreateTags')
DeleteChannel = Action('DeleteChannel')
DeleteInput = Action('DeleteInput')
DeleteInputSecurityGroup = Action('DeleteInputSecurityGroup')
DeleteMultiplex = Action('DeleteMultiplex')
DeleteMultiplexProgram = Action('DeleteMultiplexProgram')
DeleteReservation = Action('DeleteReservation')
DeleteSchedule = Action('DeleteSchedule')
DeleteTags = Action('DeleteTags')
DescribeChannel = Action('DescribeChannel')
DescribeInput = Action('DescribeInput')
DescribeInputDevice = Action('DescribeInputDevice')
DescribeInputDeviceThumbnail = Action('DescribeInputDeviceThumbnail')
DescribeInputSecurityGroup = Action('DescribeInputSecurityGroup')
DescribeMultiplex = Action('DescribeMultiplex')
DescribeMultiplexProgram = Action('DescribeMultiplexProgram')
DescribeOffering = Action('DescribeOffering')
DescribeReservation = Action('DescribeReservation')
DescribeSchedule = Action('DescribeSchedule')
ListChannels = Action('ListChannels')
ListInputDeviceTransfers = Action('ListInputDeviceTransfers')
ListInputDevices = Action('ListInputDevices')
ListInputSecurityGroups = Action('ListInputSecurityGroups')
ListInputs = Action('ListInputs')
ListMultiplexPrograms = Action('ListMultiplexPrograms')
ListMultiplexes = Action('ListMultiplexes')
ListOfferings = Action('ListOfferings')
ListReservations = Action('ListReservations')
ListTagsForResource = Action('ListTagsForResource')
PurchaseOffering = Action('PurchaseOffering')
RejectInputDeviceTransfer = Action('RejectInputDeviceTransfer')
StartChannel = Action('StartChannel')
StartMultiplex = Action('StartMultiplex')
StopChannel = Action('StopChannel')
StopMultiplex = Action('StopMultiplex')
TransferInputDevice = Action('TransferInputDevice')
UpdateChannel = Action('UpdateChannel')
UpdateChannelClass = Action('UpdateChannelClass')
UpdateInput = Action('UpdateInput')
UpdateInputDevice = Action('UpdateInputDevice')
UpdateInputSecurityGroup = Action('UpdateInputSecurityGroup')
UpdateMultiplex = Action('UpdateMultiplex')
UpdateMultiplexProgram = Action('UpdateMultiplexProgram')
UpdateReservation = Action('UpdateReservation')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS License Manager'
prefix = 'license-manager'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptGrant = Action('AcceptGrant')
CheckInLicense = Action('CheckInLicense')
CheckoutBorrowLicense = Action('CheckoutBorrowLicense')
CheckoutLicense = Action('CheckoutLicense')
CreateGrant = Action('CreateGrant')
CreateGrantVersion = Action('CreateGrantVersion')
CreateLicense = Action('CreateLicense')
CreateLicenseConfiguration = Action('CreateLicenseConfiguration')
CreateLicenseVersion = Action('CreateLicenseVersion')
CreateToken = Action('CreateToken')
DeleteGrant = Action('DeleteGrant')
DeleteLicense = Action('DeleteLicense')
DeleteLicenseConfiguration = Action('DeleteLicenseConfiguration')
DeleteToken = Action('DeleteToken')
ExtendLicenseConsumption = Action('ExtendLicenseConsumption')
GetAccessToken = Action('GetAccessToken')
GetGrant = Action('GetGrant')
GetLicense = Action('GetLicense')
GetLicenseConfiguration = Action('GetLicenseConfiguration')
GetLicenseUsage = Action('GetLicenseUsage')
GetServiceSettings = Action('GetServiceSettings')
ListAssociationsForLicenseConfiguration = \
    Action('ListAssociationsForLicenseConfiguration')
ListDistributedGrants = Action('ListDistributedGrants')
ListFailuresForLicenseConfigurationOperations = \
    Action('ListFailuresForLicenseConfigurationOperations')
ListLicenseConfigurations = Action('ListLicenseConfigurations')
ListLicenseSpecificationsForResource = \
    Action('ListLicenseSpecificationsForResource')
ListLicenseVersions = Action('ListLicenseVersions')
ListLicenses = Action('ListLicenses')
ListReceivedGrants = Action('ListReceivedGrants')
ListReceivedLicenses = Action('ListReceivedLicenses')
ListResourceInventory = Action('ListResourceInventory')
ListTagsForResource = Action('ListTagsForResource')
ListTokens = Action('ListTokens')
ListUsageForLicenseConfiguration = \
    Action('ListUsageForLicenseConfiguration')
RejectGrant = Action('RejectGrant')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateLicenseConfiguration = Action('UpdateLicenseConfiguration')
UpdateLicenseSpecificationsForResource = \
    Action('UpdateLicenseSpecificationsForResource')
UpdateServiceSettings = Action('UpdateServiceSettings')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Managed Streaming for Apache Kafka'
prefix = 'kafka'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchAssociateScramSecret = Action('BatchAssociateScramSecret')
BatchDisassociateScramSecret = Action('BatchDisassociateScramSecret')
CreateCluster = Action('CreateCluster')
CreateConfiguration = Action('CreateConfiguration')
DeleteCluster = Action('DeleteCluster')
DeleteConfiguration = Action('DeleteConfiguration')
DescribeCluster = Action('DescribeCluster')
DescribeClusterOperation = Action('DescribeClusterOperation')
DescribeConfiguration = Action('DescribeConfiguration')
DescribeConfigurationRevision = Action('DescribeConfigurationRevision')
GetBootstrapBrokers = Action('GetBootstrapBrokers')
GetCompatibleKafkaVersions = Action('GetCompatibleKafkaVersions')
ListClusterOperations = Action('ListClusterOperations')
ListClusters = Action('ListClusters')
ListConfigurationRevisions = Action('ListConfigurationRevisions')
ListConfigurations = Action('ListConfigurations')
ListKafkaVersions = Action('ListKafkaVersions')
ListNodes = Action('ListNodes')
ListScramSecrets = Action('ListScramSecrets')
ListTagsForResource = Action('ListTagsForResource')
RebootBroker = Action('RebootBroker')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateBrokerCount = Action('UpdateBrokerCount')
UpdateBrokerStorage = Action('UpdateBrokerStorage')
UpdateBrokerType = Action('UpdateBrokerType')
UpdateClusterConfiguration = Action('UpdateClusterConfiguration')
UpdateClusterKafkaVersion = Action('UpdateClusterKafkaVersion')
UpdateConfiguration = Action('UpdateConfiguration')
UpdateMonitoring = Action('UpdateMonitoring')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Well-Architected Tool'
prefix = 'wellarchitected'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateLenses = Action('AssociateLenses')
CreateMilestone = Action('CreateMilestone')
CreateWorkload = Action('CreateWorkload')
CreateWorkloadShare = Action('CreateWorkloadShare')
DeleteWorkload = Action('DeleteWorkload')
DeleteWorkloadShare = Action('DeleteWorkloadShare')
DisassociateLenses = Action('DisassociateLenses')
GetAnswer = Action('GetAnswer')
GetLensReview = Action('GetLensReview')
GetLensReviewReport = Action('GetLensReviewReport')
GetLensVersionDifference = Action('GetLensVersionDifference')
GetMilestone = Action('GetMilestone')
GetWorkload = Action('GetWorkload')
ListAnswers = Action('ListAnswers')
ListLensReviewImprovements = Action('ListLensReviewImprovements')
ListLensReviews = Action('ListLensReviews')
ListLenses = Action('ListLenses')
ListMilestones = Action('ListMilestones')
ListNotifications = Action('ListNotifications')
ListShareInvitations = Action('ListShareInvitations')
ListTagsForResource = Action('ListTagsForResource')
ListWorkloadShares = Action('ListWorkloadShares')
ListWorkloads = Action('ListWorkloads')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAnswer = Action('UpdateAnswer')
UpdateLensReview = Action('UpdateLensReview')
UpdateShareInvitation = Action('UpdateShareInvitation')
UpdateWorkload = Action('UpdateWorkload')
UpdateWorkloadShare = Action('UpdateWorkloadShare')
UpgradeLensReview = Action('UpgradeLensReview')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Service Quotas'
prefix = 'servicequotas'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateServiceQuotaTemplate = Action('AssociateServiceQuotaTemplate')
DeleteServiceQuotaIncreaseRequestFromTemplate = \
    Action('DeleteServiceQuotaIncreaseRequestFromTemplate')
DisassociateServiceQuotaTemplate = \
    Action('DisassociateServiceQuotaTemplate')
GetAWSDefaultServiceQuota = Action('GetAWSDefaultServiceQuota')
GetAssociationForServiceQuotaTemplate = \
    Action('GetAssociationForServiceQuotaTemplate')
GetRequestedServiceQuotaChange = Action('GetRequestedServiceQuotaChange')
GetServiceQuota = Action('GetServiceQuota')
GetServiceQuotaIncreaseRequestFromTemplate = \
    Action('GetServiceQuotaIncreaseRequestFromTemplate')
ListAWSDefaultServiceQuotas = Action('ListAWSDefaultServiceQuotas')
ListRequestedServiceQuotaChangeHistory = \
    Action('ListRequestedServiceQuotaChangeHistory')
ListRequestedServiceQuotaChangeHistoryByQuota = \
    Action('ListRequestedServiceQuotaChangeHistoryByQuota')
ListServiceQuotaIncreaseRequestsInTemplate = \
    Action('ListServiceQuotaIncreaseRequestsInTemplate')
ListServiceQuotas = Action('ListServiceQuotas')
ListServices = Action('ListServices')
ListTagsForResource = Action('ListTagsForResource')
PutServiceQuotaIncreaseRequestIntoTemplate = \
    Action('PutServiceQuotaIncreaseRequestIntoTemplate')
RequestServiceQuotaIncrease = Action('RequestServiceQuotaIncrease')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon EC2 Image Builder'
prefix = 'imagebuilder'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelImageCreation = Action('CancelImageCreation')
CreateComponent = Action('CreateComponent')
CreateContainerRecipe = Action('CreateContainerRecipe')
CreateDistributionConfiguration = \
    Action('CreateDistributionConfiguration')
CreateImage = Action('CreateImage')
CreateImagePipeline = Action('CreateImagePipeline')
CreateImageRecipe = Action('CreateImageRecipe')
CreateInfrastructureConfiguration = \
    Action('CreateInfrastructureConfiguration')
DeleteComponent = Action('DeleteComponent')
DeleteContainerRecipe = Action('DeleteContainerRecipe')
DeleteDistributionConfiguration = \
    Action('DeleteDistributionConfiguration')
DeleteImage = Action('DeleteImage')
DeleteImagePipeline = Action('DeleteImagePipeline')
DeleteImageRecipe = Action('DeleteImageRecipe')
DeleteInfrastructureConfiguration = \
    Action('DeleteInfrastructureConfiguration')
GetComponent = Action('GetComponent')
GetComponentPolicy = Action('GetComponentPolicy')
GetContainerRecipe = Action('GetContainerRecipe')
GetContainerRecipePolicy = Action('GetContainerRecipePolicy')
GetDistributionConfiguration = Action('GetDistributionConfiguration')
GetImage = Action('GetImage')
GetImagePipeline = Action('GetImagePipeline')
GetImagePolicy = Action('GetImagePolicy')
GetImageRecipe = Action('GetImageRecipe')
GetImageRecipePolicy = Action('GetImageRecipePolicy')
GetInfrastructureConfiguration = Action('GetInfrastructureConfiguration')
ListComponentBuildVersions = Action('ListComponentBuildVersions')
ListComponents = Action('ListComponents')
ListContainerRecipes = Action('ListContainerRecipes')
ListDistributionConfigurations = Action('ListDistributionConfigurations')
ListImageBuildVersions = Action('ListImageBuildVersions')
ListImagePackages = Action('ListImagePackages')
ListImagePipelineImages = Action('ListImagePipelineImages')
ListImagePipelines = Action('ListImagePipelines')
ListImageRecipes = Action('ListImageRecipes')
ListImages = Action('ListImages')
ListInfrastructureConfigurations = \
    Action('ListInfrastructureConfigurations')
ListTagsForResource = Action('ListTagsForResource')
PutComponentPolicy = Action('PutComponentPolicy')
PutContainerRecipePolicy = Action('PutContainerRecipePolicy')
PutImagePolicy = Action('PutImagePolicy')
PutImageRecipePolicy = Action('PutImageRecipePolicy')
StartImagePipelineExecution = Action('StartImagePipelineExecution')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDistributionConfiguration = \
    Action('UpdateDistributionConfiguration')
UpdateImagePipeline = Action('UpdateImagePipeline')
UpdateInfrastructureConfiguration = \
    Action('UpdateInfrastructureConfiguration')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon S3 on Outposts'
prefix = 's3-outposts'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AbortMultipartUpload = Action('AbortMultipartUpload')
CreateAccessPoint = Action('CreateAccessPoint')
CreateBucket = Action('CreateBucket')
CreateEndpoint = Action('CreateEndpoint')
DeleteAccessPoint = Action('DeleteAccessPoint')
DeleteAccessPointPolicy = Action('DeleteAccessPointPolicy')
DeleteBucket = Action('DeleteBucket')
DeleteBucketPolicy = Action('DeleteBucketPolicy')
DeleteEndpoint = Action('DeleteEndpoint')
DeleteObject = Action('DeleteObject')
DeleteObjectTagging = Action('DeleteObjectTagging')
GetAccessPoint = Action('GetAccessPoint')
GetAccessPointPolicy = Action('GetAccessPointPolicy')
GetBucket = Action('GetBucket')
GetBucketPolicy = Action('GetBucketPolicy')
GetBucketTagging = Action('GetBucketTagging')
GetLifecycleConfiguration = Action('GetLifecycleConfiguration')
GetObject = Action('GetObject')
GetObjectTagging = Action('GetObjectTagging')
ListAccessPoints = Action('ListAccessPoints')
ListBucket = Action('ListBucket')
ListBucketMultipartUploads = Action('ListBucketMultipartUploads')
ListEndpoints = Action('ListEndpoints')
ListMultipartUploadParts = Action('ListMultipartUploadParts')
ListRegionalBuckets = Action('ListRegionalBuckets')
PutAccessPointPolicy = Action('PutAccessPointPolicy')
PutBucketPolicy = Action('PutBucketPolicy')
PutBucketTagging = Action('PutBucketTagging')
PutLifecycleConfiguration = Action('PutLifecycleConfiguration')
PutObject = Action('PutObject')
PutObjectAcl = Action('PutObjectAcl')
PutObjectTagging = Action('PutObjectTagging')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lookout for Equipment'
prefix = 'lookoutequipment'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateDataset = Action('CreateDataset')
CreateInferenceScheduler = Action('CreateInferenceScheduler')
CreateModel = Action('CreateModel')
DeleteDataset = Action('DeleteDataset')
DeleteInferenceScheduler = Action('DeleteInferenceScheduler')
DeleteModel = Action('DeleteModel')
DescribeDataIngestionJob = Action('DescribeDataIngestionJob')
DescribeDataset = Action('DescribeDataset')
DescribeInferenceScheduler = Action('DescribeInferenceScheduler')
DescribeModel = Action('DescribeModel')
ListDataIngestionJobs = Action('ListDataIngestionJobs')
ListDatasets = Action('ListDatasets')
ListInferenceExecutions = Action('ListInferenceExecutions')
ListInferenceSchedulers = Action('ListInferenceSchedulers')
ListModels = Action('ListModels')
ListTagsForResource = Action('ListTagsForResource')
StartDataIngestionJob = Action('StartDataIngestionJob')
StartInferenceScheduler = Action('StartInferenceScheduler')
StopInferenceScheduler = Action('StopInferenceScheduler')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateInferenceScheduler = Action('UpdateInferenceScheduler')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon CodeGuru Reviewer'
prefix = 'codeguru-reviewer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateRepository = Action('AssociateRepository')
CreateConnectionToken = Action('CreateConnectionToken')
DescribeCodeReview = Action('DescribeCodeReview')
DescribeRecommendationFeedback = Action('DescribeRecommendationFeedback')
DescribeRepositoryAssociation = Action('DescribeRepositoryAssociation')
DisassociateRepository = Action('DisassociateRepository')
GetMetricsData = Action('GetMetricsData')
ListCodeReviews = Action('ListCodeReviews')
ListRecommendationFeedback = Action('ListRecommendationFeedback')
ListRecommendations = Action('ListRecommendations')
ListRepositoryAssociations = Action('ListRepositoryAssociations')
ListThirdPartyRepositories = Action('ListThirdPartyRepositories')
PutRecommendationFeedback = Action('PutRecommendationFeedback')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Data Exchange'
prefix = 'dataexchange'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelJob = Action('CancelJob')
CreateAsset = Action('CreateAsset')
CreateDataSet = Action('CreateDataSet')
CreateJob = Action('CreateJob')
CreateRevision = Action('CreateRevision')
DeleteAsset = Action('DeleteAsset')
DeleteDataSet = Action('DeleteDataSet')
DeleteRevision = Action('DeleteRevision')
GetAsset = Action('GetAsset')
GetDataSet = Action('GetDataSet')
GetJob = Action('GetJob')
GetRevision = Action('GetRevision')
ListDataSetRevisions = Action('ListDataSetRevisions')
ListDataSets = Action('ListDataSets')
ListJobs = Action('ListJobs')
ListRevisionAssets = Action('ListRevisionAssets')
ListTagsForResource = Action('ListTagsForResource')
StartJob = Action('StartJob')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAsset = Action('UpdateAsset')
UpdateDataSet = Action('UpdateDataSet')
UpdateRevision = Action('UpdateRevision')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon HealthLake'
prefix = 'healthlake'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateFHIRDatastore = Action('CreateFHIRDatastore')
CreateResource = Action('CreateResource')
DeleteFHIRDatastore = Action('DeleteFHIRDatastore')
DeleteResource = Action('DeleteResource')
DescribeFHIRDatastore = Action('DescribeFHIRDatastore')
DescribeFHIRExportJob = Action('DescribeFHIRExportJob')
DescribeFHIRImportJob = Action('DescribeFHIRImportJob')
GetCapabilities = Action('GetCapabilities')
ListFHIRDatastores = Action('ListFHIRDatastores')
ReadResource = Action('ReadResource')
SearchWithGet = Action('SearchWithGet')
SearchWithPost = Action('SearchWithPost')
StartFHIRExportJob = Action('StartFHIRExportJob')
StartFHIRImportJob = Action('StartFHIRImportJob')
UpdateResource = Action('UpdateResource')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Detective'
prefix = 'detective'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptInvitation = Action('AcceptInvitation')
CreateGraph = Action('CreateGraph')
CreateMembers = Action('CreateMembers')
DeleteGraph = Action('DeleteGraph')
DeleteMembers = Action('DeleteMembers')
DisassociateMembership = Action('DisassociateMembership')
GetFreeTrialEligibility = Action('GetFreeTrialEligibility')
GetGraphIngestState = Action('GetGraphIngestState')
GetMembers = Action('GetMembers')
GetPricingInformation = Action('GetPricingInformation')
GetUsageInformation = Action('GetUsageInformation')
ListGraphs = Action('ListGraphs')
ListInvitations = Action('ListInvitations')
ListMembers = Action('ListMembers')
RejectInvitation = Action('RejectInvitation')
SearchGraph = Action('SearchGraph')
StartMonitoringMember = Action('StartMonitoringMember')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Budget Service'
prefix = 'budgets'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateBudgetAction = Action('CreateBudgetAction')
DeleteBudgetAction = Action('DeleteBudgetAction')
DescribeBudgetAction = Action('DescribeBudgetAction')
DescribeBudgetActionHistories = Action('DescribeBudgetActionHistories')
DescribeBudgetActionsForAccount = \
    Action('DescribeBudgetActionsForAccount')
DescribeBudgetActionsForBudget = Action('DescribeBudgetActionsForBudget')
ExecuteBudgetAction = Action('ExecuteBudgetAction')
ModifyBudget = Action('ModifyBudget')
UpdateBudgetAction = Action('UpdateBudgetAction')
ViewBudget = Action('ViewBudget')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lookout for Vision'
prefix = 'lookoutvision'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateDataset = Action('CreateDataset')
CreateModel = Action('CreateModel')
CreateProject = Action('CreateProject')
DeleteDataset = Action('DeleteDataset')
DeleteModel = Action('DeleteModel')
DeleteProject = Action('DeleteProject')
DescribeDataset = Action('DescribeDataset')
DescribeModel = Action('DescribeModel')
DescribeProject = Action('DescribeProject')
DescribeTrialDetection = Action('DescribeTrialDetection')
DetectAnomalies = Action('DetectAnomalies')
ListDatasetEntries = Action('ListDatasetEntries')
ListModels = Action('ListModels')
ListProjects = Action('ListProjects')
ListTagsForResource = Action('ListTagsForResource')
ListTrialDetections = Action('ListTrialDetections')
StartModel = Action('StartModel')
StartTrialDetection = Action('StartTrialDetection')
StopModel = Action('StopModel')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDatasetEntries = Action('UpdateDatasetEntries')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Personalize'
prefix = 'personalize'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateBatchInferenceJob = Action('CreateBatchInferenceJob')
CreateCampaign = Action('CreateCampaign')
CreateDataset = Action('CreateDataset')
CreateDatasetGroup = Action('CreateDatasetGroup')
CreateDatasetImportJob = Action('CreateDatasetImportJob')
CreateEventTracker = Action('CreateEventTracker')
CreateFilter = Action('CreateFilter')
CreateSchema = Action('CreateSchema')
CreateSolution = Action('CreateSolution')
CreateSolutionVersion = Action('CreateSolutionVersion')
DeleteCampaign = Action('DeleteCampaign')
DeleteDataset = Action('DeleteDataset')
DeleteDatasetGroup = Action('DeleteDatasetGroup')
DeleteEventTracker = Action('DeleteEventTracker')
DeleteFilter = Action('DeleteFilter')
DeleteSchema = Action('DeleteSchema')
DeleteSolution = Action('DeleteSolution')
DescribeAlgorithm = Action('DescribeAlgorithm')
DescribeBatchInferenceJob = Action('DescribeBatchInferenceJob')
DescribeCampaign = Action('DescribeCampaign')
DescribeDataset = Action('DescribeDataset')
DescribeDatasetGroup = Action('DescribeDatasetGroup')
DescribeDatasetImportJob = Action('DescribeDatasetImportJob')
DescribeEventTracker = Action('DescribeEventTracker')
DescribeFeatureTransformation = Action('DescribeFeatureTransformation')
DescribeFilter = Action('DescribeFilter')
DescribeRecipe = Action('DescribeRecipe')
DescribeSchema = Action('DescribeSchema')
DescribeSolution = Action('DescribeSolution')
DescribeSolutionVersion = Action('DescribeSolutionVersion')
GetPersonalizedRanking = Action('GetPersonalizedRanking')
GetRecommendations = Action('GetRecommendations')
GetSolutionMetrics = Action('GetSolutionMetrics')
ListBatchInferenceJobs = Action('ListBatchInferenceJobs')
ListCampaigns = Action('ListCampaigns')
ListDatasetGroups = Action('ListDatasetGroups')
ListDatasetImportJobs = Action('ListDatasetImportJobs')
ListDatasets = Action('ListDatasets')
ListEventTrackers = Action('ListEventTrackers')
ListFilters = Action('ListFilters')
ListRecipes = Action('ListRecipes')
ListSchemas = Action('ListSchemas')
ListSolutionVersions = Action('ListSolutionVersions')
ListSolutions = Action('ListSolutions')
PutEvents = Action('PutEvents')
PutItems = Action('PutItems')
PutUsers = Action('PutUsers')
UpdateCampaign = Action('UpdateCampaign')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Connector Service'
prefix = 'awsconnector'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


GetConnectorHealth = Action('GetConnectorHealth')
RegisterConnector = Action('RegisterConnector')
ValidateConnectorId = Action('ValidateConnectorId')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon DevOps Guru'
prefix = 'devops-guru'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddNotificationChannel = Action('AddNotificationChannel')
DescribeAccountHealth = Action('DescribeAccountHealth')
DescribeAccountOverview = Action('DescribeAccountOverview')
DescribeAnomaly = Action('DescribeAnomaly')
DescribeInsight = Action('DescribeInsight')
DescribeResourceCollectionHealth = \
    Action('DescribeResourceCollectionHealth')
DescribeServiceIntegration = Action('DescribeServiceIntegration')
GetResourceCollection = Action('GetResourceCollection')
ListAnomaliesForInsight = Action('ListAnomaliesForInsight')
ListEvents = Action('ListEvents')
ListInsights = Action('ListInsights')
ListNotificationChannels = Action('ListNotificationChannels')
ListRecommendations = Action('ListRecommendations')
PutFeedback = Action('PutFeedback')
RemoveNotificationChannel = Action('RemoveNotificationChannel')
SearchInsights = Action('SearchInsights')
UpdateResourceCollection = Action('UpdateResourceCollection')
UpdateServiceIntegration = Action('UpdateServiceIntegration')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon QLDB'
prefix = 'qldb'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelJournalKinesisStream = Action('CancelJournalKinesisStream')
CreateLedger = Action('CreateLedger')
DeleteLedger = Action('DeleteLedger')
DescribeJournalKinesisStream = Action('DescribeJournalKinesisStream')
DescribeJournalS3Export = Action('DescribeJournalS3Export')
DescribeLedger = Action('DescribeLedger')
ExecuteStatement = Action('ExecuteStatement')
ExportJournalToS3 = Action('ExportJournalToS3')
GetBlock = Action('GetBlock')
GetDigest = Action('GetDigest')
GetRevision = Action('GetRevision')
InsertSampleData = Action('InsertSampleData')
ListJournalKinesisStreamsForLedger = \
    Action('ListJournalKinesisStreamsForLedger')
ListJournalS3Exports = Action('ListJournalS3Exports')
ListJournalS3ExportsForLedger = Action('ListJournalS3ExportsForLedger')
ListLedgers = Action('ListLedgers')
ListTagsForResource = Action('ListTagsForResource')
SendCommand = Action('SendCommand')
ShowCatalog = Action('ShowCatalog')
StreamJournalToKinesis = Action('StreamJournalToKinesis')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateLedger = Action('UpdateLedger')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Amplify Admin'
prefix = 'amplifybackend'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CloneBackend = Action('CloneBackend')
CreateBackend = Action('CreateBackend')
CreateBackendAPI = Action('CreateBackendAPI')
CreateBackendAuth = Action('CreateBackendAuth')
CreateBackendConfig = Action('CreateBackendConfig')
CreateToken = Action('CreateToken')
DeleteBackend = Action('DeleteBackend')
DeleteBackendAPI = Action('DeleteBackendAPI')
DeleteBackendAuth = Action('DeleteBackendAuth')
DeleteToken = Action('DeleteToken')
GenerateBackendAPIModels = Action('GenerateBackendAPIModels')
GetBackend = Action('GetBackend')
GetBackendAPI = Action('GetBackendAPI')
GetBackendAPIModels = Action('GetBackendAPIModels')
GetBackendAuth = Action('GetBackendAuth')
GetBackendJob = Action('GetBackendJob')
GetToken = Action('GetToken')
ListBackendJobs = Action('ListBackendJobs')
RemoveAllBackends = Action('RemoveAllBackends')
RemoveBackendConfig = Action('RemoveBackendConfig')
UpdateBackendAPI = Action('UpdateBackendAPI')
UpdateBackendAuth = Action('UpdateBackendAuth')
UpdateBackendConfig = Action('UpdateBackendConfig')
UpdateBackendJob = Action('UpdateBackendJob')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon AppFlow'
prefix = 'appflow'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateConnectorProfile = Action('CreateConnectorProfile')
CreateFlow = Action('CreateFlow')
DeleteConnectorProfile = Action('DeleteConnectorProfile')
DeleteFlow = Action('DeleteFlow')
DescribeConnectorEntity = Action('DescribeConnectorEntity')
DescribeConnectorFields = Action('DescribeConnectorFields')
DescribeConnectorProfiles = Action('DescribeConnectorProfiles')
DescribeConnectors = Action('DescribeConnectors')
DescribeFlow = Action('DescribeFlow')
DescribeFlowExecution = Action('DescribeFlowExecution')
DescribeFlowExecutionRecords = Action('DescribeFlowExecutionRecords')
DescribeFlows = Action('DescribeFlows')
ListConnectorEntities = Action('ListConnectorEntities')
ListConnectorFields = Action('ListConnectorFields')
ListFlows = Action('ListFlows')
ListTagsForResource = Action('ListTagsForResource')
RunFlow = Action('RunFlow')
StartFlow = Action('StartFlow')
StopFlow = Action('StopFlow')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateConnectorProfile = Action('UpdateConnectorProfile')
UpdateFlow = Action('UpdateFlow')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon SES'
prefix = 'ses'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CloneReceiptRuleSet = Action('CloneReceiptRuleSet')
CreateConfigurationSet = Action('CreateConfigurationSet')
CreateConfigurationSetEventDestination = \
    Action('CreateConfigurationSetEventDestination')
CreateConfigurationSetTrackingOptions = \
    Action('CreateConfigurationSetTrackingOptions')
CreateContact = Action('CreateContact')
CreateContactList = Action('CreateContactList')
CreateCustomVerificationEmailTemplate = \
    Action('CreateCustomVerificationEmailTemplate')
CreateDedicatedIpPool = Action('CreateDedicatedIpPool')
CreateDeliverabilityTestReport = Action('CreateDeliverabilityTestReport')
CreateEmailIdentity = Action('CreateEmailIdentity')
CreateEmailIdentityPolicy = Action('CreateEmailIdentityPolicy')
CreateEmailTemplate = Action('CreateEmailTemplate')
CreateImportJob = Action('CreateImportJob')
CreateReceiptFilter = Action('CreateReceiptFilter')
CreateReceiptRule = Action('CreateReceiptRule')
CreateReceiptRuleSet = Action('CreateReceiptRuleSet')
CreateTemplate = Action('CreateTemplate')
DeleteConfigurationSet = Action('DeleteConfigurationSet')
DeleteConfigurationSetEventDestination = \
    Action('DeleteConfigurationSetEventDestination')
DeleteConfigurationSetTrackingOptions = \
    Action('DeleteConfigurationSetTrackingOptions')
DeleteContact = Action('DeleteContact')
DeleteContactList = Action('DeleteContactList')
DeleteCustomVerificationEmailTemplate = \
    Action('DeleteCustomVerificationEmailTemplate')
DeleteDedicatedIpPool = Action('DeleteDedicatedIpPool')
DeleteEmailIdentity = Action('DeleteEmailIdentity')
DeleteEmailIdentityPolicy = Action('DeleteEmailIdentityPolicy')
DeleteEmailTemplate = Action('DeleteEmailTemplate')
DeleteIdentity = Action('DeleteIdentity')
DeleteIdentityPolicy = Action('DeleteIdentityPolicy')
DeleteReceiptFilter = Action('DeleteReceiptFilter')
DeleteReceiptRule = Action('DeleteReceiptRule')
DeleteReceiptRuleSet = Action('DeleteReceiptRuleSet')
DeleteSuppressedDestination = Action('DeleteSuppressedDestination')
DeleteTemplate = Action('DeleteTemplate')
DeleteVerifiedEmailAddress = Action('DeleteVerifiedEmailAddress')
DescribeActiveReceiptRuleSet = Action('DescribeActiveReceiptRuleSet')
DescribeConfigurationSet = Action('DescribeConfigurationSet')
DescribeReceiptRule = Action('DescribeReceiptRule')
DescribeReceiptRuleSet = Action('DescribeReceiptRuleSet')
GetAccount = Action('GetAccount')
GetAccountSendingEnabled = Action('GetAccountSendingEnabled')
GetBlacklistReports = Action('GetBlacklistReports')
GetConfigurationSet = Action('GetConfigurationSet')
GetConfigurationSetEventDestinations = \
    Action('GetConfigurationSetEventDestinations')
GetContact = Action('GetContact')
GetContactList = Action('GetContactList')
GetCustomVerificationEmailTemplate = \
    Action('GetCustomVerificationEmailTemplate')
GetDedicatedIp = Action('GetDedicatedIp')
GetDedicatedIps = Action('GetDedicatedIps')
GetDeliverabilityDashboardOptions = \
    Action('GetDeliverabilityDashboardOptions')
GetDeliverabilityTestReport = Action('GetDeliverabilityTestReport')
GetDomainDeliverabilityCampaign = \
    Action('GetDomainDeliverabilityCampaign')
GetDomainStatisticsReport = Action('GetDomainStatisticsReport')
GetEmailIdentity = Action('GetEmailIdentity')
GetEmailIdentityPolicies = Action('GetEmailIdentityPolicies')
GetEmailTemplate = Action('GetEmailTemplate')
GetIdentityDkimAttributes = Action('GetIdentityDkimAttributes')
GetIdentityMailFromDomainAttributes = \
    Action('GetIdentityMailFromDomainAttributes')
GetIdentityNotificationAttributes = \
    Action('GetIdentityNotificationAttributes')
GetIdentityPolicies = Action('GetIdentityPolicies')
GetIdentityVerificationAttributes = \
    Action('GetIdentityVerificationAttributes')
GetImportJob = Action('GetImportJob')
GetSendQuota = Action('GetSendQuota')
GetSendStatistics = Action('GetSendStatistics')
GetSuppressedDestination = Action('GetSuppressedDestination')
GetTemplate = Action('GetTemplate')
ListConfigurationSets = Action('ListConfigurationSets')
ListContactLists = Action('ListContactLists')
ListContacts = Action('ListContacts')
ListCustomVerificationEmailTemplates = \
    Action('ListCustomVerificationEmailTemplates')
ListDedicatedIpPools = Action('ListDedicatedIpPools')
ListDeliverabilityTestReports = Action('ListDeliverabilityTestReports')
ListDomainDeliverabilityCampaigns = \
    Action('ListDomainDeliverabilityCampaigns')
ListEmailIdentities = Action('ListEmailIdentities')
ListEmailTemplates = Action('ListEmailTemplates')
ListIdentities = Action('ListIdentities')
ListIdentityPolicies = Action('ListIdentityPolicies')
ListImportJobs = Action('ListImportJobs')
ListReceiptFilters = Action('ListReceiptFilters')
ListReceiptRuleSets = Action('ListReceiptRuleSets')
ListSuppressedDestinations = Action('ListSuppressedDestinations')
ListTagsForResource = Action('ListTagsForResource')
ListTemplates = Action('ListTemplates')
ListVerifiedEmailAddresses = Action('ListVerifiedEmailAddresses')
PutAccountDedicatedIpWarmupAttributes = \
    Action('PutAccountDedicatedIpWarmupAttributes')
PutAccountDetails = Action('PutAccountDetails')
PutAccountSendingAttributes = Action('PutAccountSendingAttributes')
PutAccountSuppressionAttributes = \
    Action('PutAccountSuppressionAttributes')
PutConfigurationSetDeliveryOptions = \
    Action('PutConfigurationSetDeliveryOptions')
PutConfigurationSetReputationOptions = \
    Action('PutConfigurationSetReputationOptions')
PutConfigurationSetSendingOptions = \
    Action('PutConfigurationSetSendingOptions')
PutConfigurationSetSuppressionOptions = \
    Action('PutConfigurationSetSuppressionOptions')
PutConfigurationSetTrackingOptions = \
    Action('PutConfigurationSetTrackingOptions')
PutDedicatedIpInPool = Action('PutDedicatedIpInPool')
PutDedicatedIpWarmupAttributes = Action('PutDedicatedIpWarmupAttributes')
PutDeliverabilityDashboardOption = \
    Action('PutDeliverabilityDashboardOption')
PutEmailIdentityConfigurationSetAttributes = \
    Action('PutEmailIdentityConfigurationSetAttributes')
PutEmailIdentityDkimAttributes = Action('PutEmailIdentityDkimAttributes')
PutEmailIdentityDkimSigningAttributes = \
    Action('PutEmailIdentityDkimSigningAttributes')
PutEmailIdentityFeedbackAttributes = \
    Action('PutEmailIdentityFeedbackAttributes')
PutEmailIdentityMailFromAttributes = \
    Action('PutEmailIdentityMailFromAttributes')
PutIdentityPolicy = Action('PutIdentityPolicy')
PutSuppressedDestination = Action('PutSuppressedDestination')
ReorderReceiptRuleSet = Action('ReorderReceiptRuleSet')
SendBounce = Action('SendBounce')
SendBulkEmail = Action('SendBulkEmail')
SendBulkTemplatedEmail = Action('SendBulkTemplatedEmail')
SendCustomVerificationEmail = Action('SendCustomVerificationEmail')
SendEmail = Action('SendEmail')
SendRawEmail = Action('SendRawEmail')
SendTemplatedEmail = Action('SendTemplatedEmail')
SetActiveReceiptRuleSet = Action('SetActiveReceiptRuleSet')
SetIdentityDkimEnabled = Action('SetIdentityDkimEnabled')
SetIdentityFeedbackForwardingEnabled = \
    Action('SetIdentityFeedbackForwardingEnabled')
SetIdentityHeadersInNotificationsEnabled = \
    Action('SetIdentityHeadersInNotificationsEnabled')
SetIdentityMailFromDomain = Action('SetIdentityMailFromDomain')
SetIdentityNotificationTopic = Action('SetIdentityNotificationTopic')
SetReceiptRulePosition = Action('SetReceiptRulePosition')
TagResource = Action('TagResource')
TestRenderEmailTemplate = Action('TestRenderEmailTemplate')
TestRenderTemplate = Action('TestRenderTemplate')
UntagResource = Action('UntagResource')
UpdateAccountSendingEnabled = Action('UpdateAccountSendingEnabled')
UpdateConfigurationSetEventDestination = \
    Action('UpdateConfigurationSetEventDestination')
UpdateConfigurationSetReputationMetricsEnabled = \
    Action('UpdateConfigurationSetReputationMetricsEnabled')
UpdateConfigurationSetSendingEnabled = \
    Action('UpdateConfigurationSetSendingEnabled')
UpdateConfigurationSetTrackingOptions = \
    Action('UpdateConfigurationSetTrackingOptions')
UpdateContact = Action('UpdateContact')
UpdateContactList = Action('UpdateContactList')
UpdateCustomVerificationEmailTemplate = \
    Action('UpdateCustomVerificationEmailTemplate')
UpdateEmailIdentityPolicy = Action('UpdateEmailIdentityPolicy')
UpdateEmailTemplate = Action('UpdateEmailTemplate')
UpdateReceiptRule = Action('UpdateReceiptRule')
UpdateTemplate = Action('UpdateTemplate')
VerifyDomainDkim = Action('VerifyDomainDkim')
VerifyDomainIdentity = Action('VerifyDomainIdentity')
VerifyEmailAddress = Action('VerifyEmailAddress')
VerifyEmailIdentity = Action('VerifyEmailIdentity')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT Core Device Advisor'
prefix = 'iotdeviceadvisor'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateSuiteDefinition = Action('CreateSuiteDefinition')
DeleteSuiteDefinition = Action('DeleteSuiteDefinition')
GetSuiteDefinition = Action('GetSuiteDefinition')
GetSuiteRun = Action('GetSuiteRun')
GetSuiteRunReport = Action('GetSuiteRunReport')
ListSuiteDefinitions = Action('ListSuiteDefinitions')
ListSuiteRuns = Action('ListSuiteRuns')
ListTagsForResource = Action('ListTagsForResource')
ListTestCases = Action('ListTestCases')
StartSuiteRun = Action('StartSuiteRun')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateSuiteDefinition = Action('UpdateSuiteDefinition')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Network Manager'
prefix = 'networkmanager'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateCustomerGateway = Action('AssociateCustomerGateway')
AssociateLink = Action('AssociateLink')
AssociateTransitGatewayConnectPeer = \
    Action('AssociateTransitGatewayConnectPeer')
CreateConnection = Action('CreateConnection')
CreateDevice = Action('CreateDevice')
CreateGlobalNetwork = Action('CreateGlobalNetwork')
CreateLink = Action('CreateLink')
CreateSite = Action('CreateSite')
DeleteConnection = Action('DeleteConnection')
DeleteDevice = Action('DeleteDevice')
DeleteGlobalNetwork = Action('DeleteGlobalNetwork')
DeleteLink = Action('DeleteLink')
DeleteSite = Action('DeleteSite')
DeregisterTransitGateway = Action('DeregisterTransitGateway')
DescribeGlobalNetworks = Action('DescribeGlobalNetworks')
DisassociateCustomerGateway = Action('DisassociateCustomerGateway')
DisassociateLink = Action('DisassociateLink')
DisassociateTransitGatewayConnectPeer = \
    Action('DisassociateTransitGatewayConnectPeer')
GetConnections = Action('GetConnections')
GetCustomerGatewayAssociations = Action('GetCustomerGatewayAssociations')
GetDevices = Action('GetDevices')
GetLinkAssociations = Action('GetLinkAssociations')
GetLinks = Action('GetLinks')
GetSites = Action('GetSites')
GetTransitGatewayConnectPeerAssociations = \
    Action('GetTransitGatewayConnectPeerAssociations')
GetTransitGatewayRegistrations = Action('GetTransitGatewayRegistrations')
ListTagsForResource = Action('ListTagsForResource')
RegisterTransitGateway = Action('RegisterTransitGateway')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateConnection = Action('UpdateConnection')
UpdateDevice = Action('UpdateDevice')
UpdateGlobalNetwork = Action('UpdateGlobalNetwork')
UpdateLink = Action('UpdateLink')
UpdateSite = Action('UpdateSite')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Monitron'
prefix = 'monitron'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateProjectAdminUser = Action('AssociateProjectAdminUser')
CreateProject = Action('CreateProject')
DeleteProject = Action('DeleteProject')
DisassociateProjectAdminUser = Action('DisassociateProjectAdminUser')
GetProject = Action('GetProject')
GetProjectAdminUser = Action('GetProjectAdminUser')
ListProjectAdminUsers = Action('ListProjectAdminUsers')
ListProjects = Action('ListProjects')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateProject = Action('UpdateProject')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Interactive Video Service'
prefix = 'ivs'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGetChannel = Action('BatchGetChannel')
BatchGetStreamKey = Action('BatchGetStreamKey')
CreateChannel = Action('CreateChannel')
CreateStreamKey = Action('CreateStreamKey')
DeleteChannel = Action('DeleteChannel')
DeletePlaybackKeyPair = Action('DeletePlaybackKeyPair')
DeleteStreamKey = Action('DeleteStreamKey')
GetChannel = Action('GetChannel')
GetPlaybackKeyPair = Action('GetPlaybackKeyPair')
GetStream = Action('GetStream')
GetStreamKey = Action('GetStreamKey')
ImportPlaybackKeyPair = Action('ImportPlaybackKeyPair')
ListChannels = Action('ListChannels')
ListPlaybackKeyPairs = Action('ListPlaybackKeyPairs')
ListStreamKeys = Action('ListStreamKeys')
ListStreams = Action('ListStreams')
ListTagsForResource = Action('ListTagsForResource')
PutMetadata = Action('PutMetadata')
StopStream = Action('StopStream')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateChannel = Action('UpdateChannel')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Connect Customer Profiles'
prefix = 'profile'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddProfileKey = Action('AddProfileKey')
CreateDomain = Action('CreateDomain')
CreateProfile = Action('CreateProfile')
DeleteDomain = Action('DeleteDomain')
DeleteIntegration = Action('DeleteIntegration')
DeleteProfile = Action('DeleteProfile')
DeleteProfileKey = Action('DeleteProfileKey')
DeleteProfileObject = Action('DeleteProfileObject')
DeleteProfileObjectType = Action('DeleteProfileObjectType')
GetDomain = Action('GetDomain')
GetIntegration = Action('GetIntegration')
GetProfileObjectType = Action('GetProfileObjectType')
GetProfileObjectTypeTemplate = Action('GetProfileObjectTypeTemplate')
ListAccountIntegrations = Action('ListAccountIntegrations')
ListDomains = Action('ListDomains')
ListIntegrations = Action('ListIntegrations')
ListProfileObjectTypeTemplates = Action('ListProfileObjectTypeTemplates')
ListProfileObjectTypes = Action('ListProfileObjectTypes')
ListProfileObjects = Action('ListProfileObjects')
ListTagsForResource = Action('ListTagsForResource')
PutIntegration = Action('PutIntegration')
PutProfileObject = Action('PutProfileObject')
PutProfileObjectType = Action('PutProfileObjectType')
SearchProfiles = Action('SearchProfiles')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDomain = Action('UpdateDomain')
UpdateProfile = Action('UpdateProfile')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon S3 Object Lambda'
prefix = 's3-object-lambda'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AbortMultipartUpload = Action('AbortMultipartUpload')
DeleteObject = Action('DeleteObject')
DeleteObjectTagging = Action('DeleteObjectTagging')
GetObject = Action('GetObject')
GetObjectAcl = Action('GetObjectAcl')
GetObjectLegalHold = Action('GetObjectLegalHold')
GetObjectRetention = Action('GetObjectRetention')
GetObjectTagging = Action('GetObjectTagging')
GetObjectVersion = Action('GetObjectVersion')
ListBucket = Action('ListBucket')
ListMultipartUploadParts = Action('ListMultipartUploadParts')
PutObject = Action('PutObject')
PutObjectAcl = Action('PutObjectAcl')
PutObjectLegalHold = Action('PutObjectLegalHold')
PutObjectRetention = Action('PutObjectRetention')
PutObjectTagging = Action('PutObjectTagging')
RestoreObject = Action('RestoreObject')
WriteGetObjectResponse = Action('WriteGetObjectResponse')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT Core for LoRaWAN'
prefix = 'iotwireless'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateAwsAccountWithPartnerAccount = \
    Action('AssociateAwsAccountWithPartnerAccount')
AssociateWirelessDeviceWithThing = \
    Action('AssociateWirelessDeviceWithThing')
AssociateWirelessGatewayWithCertificate = \
    Action('AssociateWirelessGatewayWithCertificate')
AssociateWirelessGatewayWithThing = \
    Action('AssociateWirelessGatewayWithThing')
CreateDestination = Action('CreateDestination')
CreateDeviceProfile = Action('CreateDeviceProfile')
CreateServiceProfile = Action('CreateServiceProfile')
CreateWirelessDevice = Action('CreateWirelessDevice')
CreateWirelessGateway = Action('CreateWirelessGateway')
CreateWirelessGatewayTask = Action('CreateWirelessGatewayTask')
CreateWirelessGatewayTaskDefinition = \
    Action('CreateWirelessGatewayTaskDefinition')
DeleteDestination = Action('DeleteDestination')
DeleteDeviceProfile = Action('DeleteDeviceProfile')
DeleteServiceProfile = Action('DeleteServiceProfile')
DeleteWirelessDevice = Action('DeleteWirelessDevice')
DeleteWirelessGateway = Action('DeleteWirelessGateway')
DeleteWirelessGatewayTask = Action('DeleteWirelessGatewayTask')
DeleteWirelessGatewayTaskDefinition = \
    Action('DeleteWirelessGatewayTaskDefinition')
DisassociateAwsAccountFromPartnerAccount = \
    Action('DisassociateAwsAccountFromPartnerAccount')
DisassociateWirelessDeviceFromThing = \
    Action('DisassociateWirelessDeviceFromThing')
DisassociateWirelessGatewayFromCertificate = \
    Action('DisassociateWirelessGatewayFromCertificate')
DisassociateWirelessGatewayFromThing = \
    Action('DisassociateWirelessGatewayFromThing')
GetDestination = Action('GetDestination')
GetDeviceProfile = Action('GetDeviceProfile')
GetPartnerAccount = Action('GetPartnerAccount')
GetServiceEndpoint = Action('GetServiceEndpoint')
GetServiceProfile = Action('GetServiceProfile')
GetWirelessDevice = Action('GetWirelessDevice')
GetWirelessDeviceStatistics = Action('GetWirelessDeviceStatistics')
GetWirelessGateway = Action('GetWirelessGateway')
GetWirelessGatewayCertificate = Action('GetWirelessGatewayCertificate')
GetWirelessGatewayFirmwareInformation = \
    Action('GetWirelessGatewayFirmwareInformation')
GetWirelessGatewayStatistics = Action('GetWirelessGatewayStatistics')
GetWirelessGatewayTask = Action('GetWirelessGatewayTask')
GetWirelessGatewayTaskDefinition = \
    Action('GetWirelessGatewayTaskDefinition')
ListDestinations = Action('ListDestinations')
ListDeviceProfiles = Action('ListDeviceProfiles')
ListPartnerAccounts = Action('ListPartnerAccounts')
ListServiceProfiles = Action('ListServiceProfiles')
ListTagsForResource = Action('ListTagsForResource')
ListWirelessDevices = Action('ListWirelessDevices')
ListWirelessGatewayTaskDefinitions = \
    Action('ListWirelessGatewayTaskDefinitions')
ListWirelessGateways = Action('ListWirelessGateways')
SendDataToWirelessDevice = Action('SendDataToWirelessDevice')
TagResource = Action('TagResource')
TestWirelessDevice = Action('TestWirelessDevice')
UntagResource = Action('UntagResource')
UpdateDestination = Action('UpdateDestination')
UpdatePartnerAccount = Action('UpdatePartnerAccount')
UpdateWirelessDevice = Action('UpdateWirelessDevice')
UpdateWirelessGateway = Action('UpdateWirelessGateway')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Managed Workflows for Apache Airflow'
prefix = 'airflow'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateCliToken = Action('CreateCliToken')
CreateEnvironment = Action('CreateEnvironment')
CreateWebLoginToken = Action('CreateWebLoginToken')
DeleteEnvironment = Action('DeleteEnvironment')
GetEnvironment = Action('GetEnvironment')
ListEnvironments = Action('ListEnvironments')
ListTagsForResource = Action('ListTagsForResource')
PublishMetrics = Action('PublishMetrics')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateEnvironment = Action('UpdateEnvironment')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS DeepRacer'
prefix = 'deepracer'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CloneReinforcementLearningModel = \
    Action('CloneReinforcementLearningModel')
CreateAccountResources = Action('CreateAccountResources')
CreateLeaderboardSubmission = Action('CreateLeaderboardSubmission')
CreateReinforcementLearningModel = \
    Action('CreateReinforcementLearningModel')
DeleteAccountResources = Action('DeleteAccountResources')
DeleteModel = Action('DeleteModel')
GetAccountResources = Action('GetAccountResources')
GetAlias = Action('GetAlias')
GetEvaluation = Action('GetEvaluation')
GetLatestUserSubmission = Action('GetLatestUserSubmission')
GetLeaderboard = Action('GetLeaderboard')
GetModel = Action('GetModel')
GetRankedUserSubmission = Action('GetRankedUserSubmission')
GetTrack = Action('GetTrack')
GetTrainingJob = Action('GetTrainingJob')
ListEvaluations = Action('ListEvaluations')
ListLeaderboardSubmissions = Action('ListLeaderboardSubmissions')
ListLeaderboards = Action('ListLeaderboards')
ListModels = Action('ListModels')
ListTracks = Action('ListTracks')
ListTrainingJobs = Action('ListTrainingJobs')
SetAlias = Action('SetAlias')
StartEvaluation = Action('StartEvaluation')
StopEvaluation = Action('StopEvaluation')
StopTrainingReinforcementLearningModel = \
    Action('StopTrainingReinforcementLearningModel')
TestRewardFunction = Action('TestRewardFunction')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Fraud Detector'
prefix = 'frauddetector'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchCreateVariable = Action('BatchCreateVariable')
BatchGetVariable = Action('BatchGetVariable')
CreateDetectorVersion = Action('CreateDetectorVersion')
CreateModel = Action('CreateModel')
CreateModelVersion = Action('CreateModelVersion')
CreateRule = Action('CreateRule')
CreateVariable = Action('CreateVariable')
DeleteDetector = Action('DeleteDetector')
DeleteDetectorVersion = Action('DeleteDetectorVersion')
DeleteEntityType = Action('DeleteEntityType')
DeleteEvent = Action('DeleteEvent')
DeleteEventType = Action('DeleteEventType')
DeleteExternalModel = Action('DeleteExternalModel')
DeleteLabel = Action('DeleteLabel')
DeleteModel = Action('DeleteModel')
DeleteModelVersion = Action('DeleteModelVersion')
DeleteOutcome = Action('DeleteOutcome')
DeleteRule = Action('DeleteRule')
DeleteVariable = Action('DeleteVariable')
DescribeDetector = Action('DescribeDetector')
DescribeModelVersions = Action('DescribeModelVersions')
GetDetectorVersion = Action('GetDetectorVersion')
GetDetectors = Action('GetDetectors')
GetEntityTypes = Action('GetEntityTypes')
GetEventPrediction = Action('GetEventPrediction')
GetEventTypes = Action('GetEventTypes')
GetExternalModels = Action('GetExternalModels')
GetKMSEncryptionKey = Action('GetKMSEncryptionKey')
GetLabels = Action('GetLabels')
GetModelVersion = Action('GetModelVersion')
GetModels = Action('GetModels')
GetOutcomes = Action('GetOutcomes')
GetRules = Action('GetRules')
GetVariables = Action('GetVariables')
ListTagsForResource = Action('ListTagsForResource')
PutDetector = Action('PutDetector')
PutEntityType = Action('PutEntityType')
PutEventType = Action('PutEventType')
PutExternalModel = Action('PutExternalModel')
PutKMSEncryptionKey = Action('PutKMSEncryptionKey')
PutLabel = Action('PutLabel')
PutOutcome = Action('PutOutcome')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDetectorVersion = Action('UpdateDetectorVersion')
UpdateDetectorVersionMetadata = Action('UpdateDetectorVersionMetadata')
UpdateDetectorVersionStatus = Action('UpdateDetectorVersionStatus')
UpdateModel = Action('UpdateModel')
UpdateModelVersion = Action('UpdateModelVersion')
UpdateModelVersionStatus = Action('UpdateModelVersionStatus')
UpdateRuleMetadata = Action('UpdateRuleMetadata')
UpdateRuleVersion = Action('UpdateRuleVersion')
UpdateVariable = Action('UpdateVariable')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Fault Injection Simulator'
prefix = 'fis'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateExperimentTemplate = Action('CreateExperimentTemplate')
DeleteExperimentTemplate = Action('DeleteExperimentTemplate')
GetAction = Action('GetAction')
GetExperiment = Action('GetExperiment')
GetExperimentTemplate = Action('GetExperimentTemplate')
InjectApiInternalError = Action('InjectApiInternalError')
InjectApiThrottleError = Action('InjectApiThrottleError')
InjectApiUnavailableError = Action('InjectApiUnavailableError')
ListActions = Action('ListActions')
ListExperimentTemplates = Action('ListExperimentTemplates')
ListExperiments = Action('ListExperiments')
ListTagsForResource = Action('ListTagsForResource')
StartExperiment = Action('StartExperiment')
StopExperiment = Action('StopExperiment')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateExperimentTemplate = Action('UpdateExperimentTemplate')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS IoT Things Graph'
prefix = 'iotthingsgraph'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateEntityToThing = Action('AssociateEntityToThing')
CreateFlowTemplate = Action('CreateFlowTemplate')
CreateSystemInstance = Action('CreateSystemInstance')
CreateSystemTemplate = Action('CreateSystemTemplate')
DeleteFlowTemplate = Action('DeleteFlowTemplate')
DeleteNamespace = Action('DeleteNamespace')
DeleteSystemInstance = Action('DeleteSystemInstance')
DeleteSystemTemplate = Action('DeleteSystemTemplate')
DeploySystemInstance = Action('DeploySystemInstance')
DeprecateFlowTemplate = Action('DeprecateFlowTemplate')
DeprecateSystemTemplate = Action('DeprecateSystemTemplate')
DescribeNamespace = Action('DescribeNamespace')
DissociateEntityFromThing = Action('DissociateEntityFromThing')
GetEntities = Action('GetEntities')
GetFlowTemplate = Action('GetFlowTemplate')
GetFlowTemplateRevisions = Action('GetFlowTemplateRevisions')
GetNamespaceDeletionStatus = Action('GetNamespaceDeletionStatus')
GetSystemInstance = Action('GetSystemInstance')
GetSystemTemplate = Action('GetSystemTemplate')
GetSystemTemplateRevisions = Action('GetSystemTemplateRevisions')
GetUploadStatus = Action('GetUploadStatus')
ListFlowExecutionMessages = Action('ListFlowExecutionMessages')
ListTagsForResource = Action('ListTagsForResource')
SearchEntities = Action('SearchEntities')
SearchFlowExecutions = Action('SearchFlowExecutions')
SearchFlowTemplates = Action('SearchFlowTemplates')
SearchSystemInstances = Action('SearchSystemInstances')
SearchSystemTemplates = Action('SearchSystemTemplates')
SearchThings = Action('SearchThings')
TagResource = Action('TagResource')
UndeploySystemInstance = Action('UndeploySystemInstance')
UntagResource = Action('UntagResource')
UpdateFlowTemplate = Action('UpdateFlowTemplate')
UpdateSystemTemplate = Action('UpdateSystemTemplate')
UploadEntityDefinitions = Action('UploadEntityDefinitions')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Forecast'
prefix = 'forecast'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateDataset = Action('CreateDataset')
CreateDatasetGroup = Action('CreateDatasetGroup')
CreateDatasetImportJob = Action('CreateDatasetImportJob')
CreateForecast = Action('CreateForecast')
CreateForecastExportJob = Action('CreateForecastExportJob')
CreatePredictor = Action('CreatePredictor')
CreatePredictorBacktestExportJob = \
    Action('CreatePredictorBacktestExportJob')
DeleteDataset = Action('DeleteDataset')
DeleteDatasetGroup = Action('DeleteDatasetGroup')
DeleteDatasetImportJob = Action('DeleteDatasetImportJob')
DeleteForecast = Action('DeleteForecast')
DeleteForecastExportJob = Action('DeleteForecastExportJob')
DeletePredictor = Action('DeletePredictor')
DeletePredictorBacktestExportJob = \
    Action('DeletePredictorBacktestExportJob')
DescribeDataset = Action('DescribeDataset')
DescribeDatasetGroup = Action('DescribeDatasetGroup')
DescribeDatasetImportJob = Action('DescribeDatasetImportJob')
DescribeForecast = Action('DescribeForecast')
DescribeForecastExportJob = Action('DescribeForecastExportJob')
DescribePredictor = Action('DescribePredictor')
DescribePredictorBacktestExportJob = \
    Action('DescribePredictorBacktestExportJob')
GetAccuracyMetrics = Action('GetAccuracyMetrics')
ListDatasetGroups = Action('ListDatasetGroups')
ListDatasetImportJobs = Action('ListDatasetImportJobs')
ListDatasets = Action('ListDatasets')
ListForecastExportJobs = Action('ListForecastExportJobs')
ListForecasts = Action('ListForecasts')
ListPredictorBacktestExportJobs = \
    Action('ListPredictorBacktestExportJobs')
ListPredictors = Action('ListPredictors')
ListTagsForResource = Action('ListTagsForResource')
QueryForecast = Action('QueryForecast')
StopResource = Action('StopResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateDatasetGroup = Action('UpdateDatasetGroup')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Ground Station'
prefix = 'groundstation'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CancelContact = Action('CancelContact')
CreateConfig = Action('CreateConfig')
CreateDataflowEndpointGroup = Action('CreateDataflowEndpointGroup')
CreateMissionProfile = Action('CreateMissionProfile')
DeleteConfig = Action('DeleteConfig')
DeleteDataflowEndpointGroup = Action('DeleteDataflowEndpointGroup')
DeleteMissionProfile = Action('DeleteMissionProfile')
DescribeContact = Action('DescribeContact')
GetConfig = Action('GetConfig')
GetDataflowEndpointGroup = Action('GetDataflowEndpointGroup')
GetMinuteUsage = Action('GetMinuteUsage')
GetMissionProfile = Action('GetMissionProfile')
GetSatellite = Action('GetSatellite')
ListConfigs = Action('ListConfigs')
ListContacts = Action('ListContacts')
ListDataflowEndpointGroups = Action('ListDataflowEndpointGroups')
ListGroundStations = Action('ListGroundStations')
ListMissionProfiles = Action('ListMissionProfiles')
ListSatellites = Action('ListSatellites')
ListTagsForResource = Action('ListTagsForResource')
ReserveContact = Action('ReserveContact')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateConfig = Action('UpdateConfig')
UpdateMissionProfile = Action('UpdateMissionProfile')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS AppConfig'
prefix = 'appconfig'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApplication = Action('CreateApplication')
CreateConfigurationProfile = Action('CreateConfigurationProfile')
CreateDeploymentStrategy = Action('CreateDeploymentStrategy')
CreateEnvironment = Action('CreateEnvironment')
CreateHostedConfigurationVersion = \
    Action('CreateHostedConfigurationVersion')
DeleteApplication = Action('DeleteApplication')
DeleteConfigurationProfile = Action('DeleteConfigurationProfile')
DeleteDeploymentStrategy = Action('DeleteDeploymentStrategy')
DeleteEnvironment = Action('DeleteEnvironment')
DeleteHostedConfigurationVersion = \
    Action('DeleteHostedConfigurationVersion')
GetApplication = Action('GetApplication')
GetConfiguration = Action('GetConfiguration')
GetConfigurationProfile = Action('GetConfigurationProfile')
GetDeployment = Action('GetDeployment')
GetDeploymentStrategy = Action('GetDeploymentStrategy')
GetEnvironment = Action('GetEnvironment')
GetHostedConfigurationVersion = Action('GetHostedConfigurationVersion')
ListApplications = Action('ListApplications')
ListConfigurationProfiles = Action('ListConfigurationProfiles')
ListDeploymentStrategies = Action('ListDeploymentStrategies')
ListDeployments = Action('ListDeployments')
ListEnvironments = Action('ListEnvironments')
ListHostedConfigurationVersions = \
    Action('ListHostedConfigurationVersions')
ListTagsForResource = Action('ListTagsForResource')
StartDeployment = Action('StartDeployment')
StopDeployment = Action('StopDeployment')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateApplication = Action('UpdateApplication')
UpdateConfigurationProfile = Action('UpdateConfigurationProfile')
UpdateDeploymentStrategy = Action('UpdateDeploymentStrategy')
UpdateEnvironment = Action('UpdateEnvironment')
ValidateConfiguration = Action('ValidateConfiguration')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lookout for Metrics'
prefix = 'lookoutmetrics'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


ActivateAnomalyDetector = Action('ActivateAnomalyDetector')
BackTestAnomalyDetector = Action('BackTestAnomalyDetector')
CreateAlert = Action('CreateAlert')
CreateAnomalyDetector = Action('CreateAnomalyDetector')
CreateMetricSet = Action('CreateMetricSet')
DeleteAlert = Action('DeleteAlert')
DeleteAnomalyDetector = Action('DeleteAnomalyDetector')
DescribeAlert = Action('DescribeAlert')
DescribeAnomalyDetectionExecutions = \
    Action('DescribeAnomalyDetectionExecutions')
DescribeAnomalyDetector = Action('DescribeAnomalyDetector')
DescribeMetricSet = Action('DescribeMetricSet')
GetAnomalyGroup = Action('GetAnomalyGroup')
GetDataQualityMetrics = Action('GetDataQualityMetrics')
GetFeedback = Action('GetFeedback')
GetSampleData = Action('GetSampleData')
ListAlerts = Action('ListAlerts')
ListAnomalyDetectors = Action('ListAnomalyDetectors')
ListAnomalyGroupSummaries = Action('ListAnomalyGroupSummaries')
ListAnomalyGroupTimeSeries = Action('ListAnomalyGroupTimeSeries')
ListMetricSets = Action('ListMetricSets')
PutFeedback = Action('PutFeedback')
UpdateAnomalyDetector = Action('UpdateAnomalyDetector')
UpdateMetricSet = Action('UpdateMetricSet')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Lex'
prefix = 'lex'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BuildBotLocale = Action('BuildBotLocale')
CreateBot = Action('CreateBot')
CreateBotAlias = Action('CreateBotAlias')
CreateBotChannel = Action('CreateBotChannel')
CreateBotLocale = Action('CreateBotLocale')
CreateBotVersion = Action('CreateBotVersion')
CreateIntent = Action('CreateIntent')
CreateIntentVersion = Action('CreateIntentVersion')
CreateSlot = Action('CreateSlot')
CreateSlotType = Action('CreateSlotType')
CreateSlotTypeVersion = Action('CreateSlotTypeVersion')
DeleteBot = Action('DeleteBot')
DeleteBotAlias = Action('DeleteBotAlias')
DeleteBotChannel = Action('DeleteBotChannel')
DeleteBotChannelAssociation = Action('DeleteBotChannelAssociation')
DeleteBotLocale = Action('DeleteBotLocale')
DeleteBotVersion = Action('DeleteBotVersion')
DeleteIntent = Action('DeleteIntent')
DeleteIntentVersion = Action('DeleteIntentVersion')
DeleteSession = Action('DeleteSession')
DeleteSlot = Action('DeleteSlot')
DeleteSlotType = Action('DeleteSlotType')
DeleteSlotTypeVersion = Action('DeleteSlotTypeVersion')
DeleteUtterances = Action('DeleteUtterances')
DescribeBot = Action('DescribeBot')
DescribeBotAlias = Action('DescribeBotAlias')
DescribeBotChannel = Action('DescribeBotChannel')
DescribeBotLocale = Action('DescribeBotLocale')
DescribeBotVersion = Action('DescribeBotVersion')
DescribeIntent = Action('DescribeIntent')
DescribeSlot = Action('DescribeSlot')
DescribeSlotType = Action('DescribeSlotType')
GetBot = Action('GetBot')
GetBotAlias = Action('GetBotAlias')
GetBotAliases = Action('GetBotAliases')
GetBotChannelAssociation = Action('GetBotChannelAssociation')
GetBotChannelAssociations = Action('GetBotChannelAssociations')
GetBotVersions = Action('GetBotVersions')
GetBots = Action('GetBots')
GetBuiltinIntent = Action('GetBuiltinIntent')
GetBuiltinIntents = Action('GetBuiltinIntents')
GetBuiltinSlotTypes = Action('GetBuiltinSlotTypes')
GetExport = Action('GetExport')
GetImport = Action('GetImport')
GetIntent = Action('GetIntent')
GetIntentVersions = Action('GetIntentVersions')
GetIntents = Action('GetIntents')
GetSession = Action('GetSession')
GetSlotType = Action('GetSlotType')
GetSlotTypeVersions = Action('GetSlotTypeVersions')
GetSlotTypes = Action('GetSlotTypes')
GetUtterancesView = Action('GetUtterancesView')
ListBotAliases = Action('ListBotAliases')
ListBotChannels = Action('ListBotChannels')
ListBotLocales = Action('ListBotLocales')
ListBotVersions = Action('ListBotVersions')
ListBots = Action('ListBots')
ListIntents = Action('ListIntents')
ListSlotTypes = Action('ListSlotTypes')
ListSlots = Action('ListSlots')
ListTagsForResource = Action('ListTagsForResource')
PostContent = Action('PostContent')
PostText = Action('PostText')
PutBot = Action('PutBot')
PutBotAlias = Action('PutBotAlias')
PutIntent = Action('PutIntent')
PutSession = Action('PutSession')
PutSlotType = Action('PutSlotType')
RecognizeSpeech = Action('RecognizeSpeech')
RecognizeText = Action('RecognizeText')
StartConversation = Action('StartConversation')
StartImport = Action('StartImport')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateBot = Action('UpdateBot')
UpdateBotAlias = Action('UpdateBotAlias')
UpdateBotLocale = Action('UpdateBotLocale')
UpdateIntent = Action('UpdateIntent')
UpdateSlot = Action('UpdateSlot')
UpdateSlotType = Action('UpdateSlotType')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Network Firewall'
prefix = 'network-firewall'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateFirewallPolicy = Action('AssociateFirewallPolicy')
AssociateSubnets = Action('AssociateSubnets')
CreateFirewall = Action('CreateFirewall')
CreateFirewallPolicy = Action('CreateFirewallPolicy')
CreateRuleGroup = Action('CreateRuleGroup')
DeleteFirewall = Action('DeleteFirewall')
DeleteFirewallPolicy = Action('DeleteFirewallPolicy')
DeleteResourcePolicy = Action('DeleteResourcePolicy')
DeleteRuleGroup = Action('DeleteRuleGroup')
DescribeFirewall = Action('DescribeFirewall')
DescribeFirewallPolicy = Action('DescribeFirewallPolicy')
DescribeLoggingConfiguration = Action('DescribeLoggingConfiguration')
DescribeResourcePolicy = Action('DescribeResourcePolicy')
DescribeRuleGroup = Action('DescribeRuleGroup')
DisassociateSubnets = Action('DisassociateSubnets')
ListFirewallPolicies = Action('ListFirewallPolicies')
ListFirewalls = Action('ListFirewalls')
ListRuleGroups = Action('ListRuleGroups')
ListTagsForResource = Action('ListTagsForResource')
PutResourcePolicy = Action('PutResourcePolicy')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateFirewallDeleteProtection = Action('UpdateFirewallDeleteProtection')
UpdateFirewallDescription = Action('UpdateFirewallDescription')
UpdateFirewallPolicy = Action('UpdateFirewallPolicy')
UpdateFirewallPolicyChangeProtection = \
    Action('UpdateFirewallPolicyChangeProtection')
UpdateLoggingConfiguration = Action('UpdateLoggingConfiguration')
UpdateRuleGroup = Action('UpdateRuleGroup')
UpdateSubnetChangeProtection = Action('UpdateSubnetChangeProtection')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Lake Formation'
prefix = 'lakeformation'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


BatchGrantPermissions = Action('BatchGrantPermissions')
BatchRevokePermissions = Action('BatchRevokePermissions')
DeregisterResource = Action('DeregisterResource')
DescribeResource = Action('DescribeResource')
GetDataAccess = Action('GetDataAccess')
GetDataLakeSettings = Action('GetDataLakeSettings')
GetEffectivePermissionsForPath = Action('GetEffectivePermissionsForPath')
GrantPermissions = Action('GrantPermissions')
ListPermissions = Action('ListPermissions')
ListResources = Action('ListResources')
PutDataLakeSettings = Action('PutDataLakeSettings')
RegisterResource = Action('RegisterResource')
RevokePermissions = Action('RevokePermissions')
UpdateResource = Action('UpdateResource')



import warnings
# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon S3'
prefix = 's3'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        # account is empty for S3
        account = ''
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


class S3_ARN(ARN):
    def __init__(self, *args, **kwargs):
        super(S3_ARN, self).__init__(*args, **kwargs)
        warnings.warn("This class is going away. Use s3.ARN instead.",
                      FutureWarning)


AbortMultipartUpload = Action('AbortMultipartUpload')
BypassGovernanceRetention = Action('BypassGovernanceRetention')
CreateAccessPoint = Action('CreateAccessPoint')
CreateAccessPointForObjectLambda = \
    Action('CreateAccessPointForObjectLambda')
CreateBucket = Action('CreateBucket')
CreateJob = Action('CreateJob')
DeleteAccessPoint = Action('DeleteAccessPoint')
DeleteAccessPointForObjectLambda = \
    Action('DeleteAccessPointForObjectLambda')
DeleteAccessPointPolicy = Action('DeleteAccessPointPolicy')
DeleteAccessPointPolicyForObjectLambda = \
    Action('DeleteAccessPointPolicyForObjectLambda')
DeleteBucket = Action('DeleteBucket')
DeleteBucketOwnershipControls = Action('DeleteBucketOwnershipControls')
DeleteBucketPolicy = Action('DeleteBucketPolicy')
DeleteBucketWebsite = Action('DeleteBucketWebsite')
DeleteJobTagging = Action('DeleteJobTagging')
DeleteObject = Action('DeleteObject')
DeleteObjectTagging = Action('DeleteObjectTagging')
DeleteObjectVersion = Action('DeleteObjectVersion')
DeleteObjectVersionTagging = Action('DeleteObjectVersionTagging')
DeleteStorageLensConfiguration = Action('DeleteStorageLensConfiguration')
DeleteStorageLensConfigurationTagging = \
    Action('DeleteStorageLensConfigurationTagging')
DescribeJob = Action('DescribeJob')
GetAccelerateConfiguration = Action('GetAccelerateConfiguration')
GetAccessPoint = Action('GetAccessPoint')
GetAccessPointConfigurationForObjectLambda = \
    Action('GetAccessPointConfigurationForObjectLambda')
GetAccessPointForObjectLambda = Action('GetAccessPointForObjectLambda')
GetAccessPointPolicy = Action('GetAccessPointPolicy')
GetAccessPointPolicyForObjectLambda = \
    Action('GetAccessPointPolicyForObjectLambda')
GetAccessPointPolicyStatus = Action('GetAccessPointPolicyStatus')
GetAccessPointPolicyStatusForObjectLambda = \
    Action('GetAccessPointPolicyStatusForObjectLambda')
GetAccountPublicAccessBlock = Action('GetAccountPublicAccessBlock')
GetAnalyticsConfiguration = Action('GetAnalyticsConfiguration')
GetBucketAcl = Action('GetBucketAcl')
GetBucketCORS = Action('GetBucketCORS')
GetBucketLocation = Action('GetBucketLocation')
GetBucketLogging = Action('GetBucketLogging')
GetBucketNotification = Action('GetBucketNotification')
GetBucketObjectLockConfiguration = \
    Action('GetBucketObjectLockConfiguration')
GetBucketOwnershipControls = Action('GetBucketOwnershipControls')
GetBucketPolicy = Action('GetBucketPolicy')
GetBucketPolicyStatus = Action('GetBucketPolicyStatus')
GetBucketPublicAccessBlock = Action('GetBucketPublicAccessBlock')
GetBucketRequestPayment = Action('GetBucketRequestPayment')
GetBucketTagging = Action('GetBucketTagging')
GetBucketVersioning = Action('GetBucketVersioning')
GetBucketWebsite = Action('GetBucketWebsite')
GetEncryptionConfiguration = Action('GetEncryptionConfiguration')
GetIntelligentTieringConfiguration = \
    Action('GetIntelligentTieringConfiguration')
GetInventoryConfiguration = Action('GetInventoryConfiguration')
GetIpConfiguration = Action('GetIpConfiguration')
GetJobTagging = Action('GetJobTagging')
GetLifecycleConfiguration = Action('GetLifecycleConfiguration')
GetMetricsConfiguration = Action('GetMetricsConfiguration')
GetObject = Action('GetObject')
GetObjectAcl = Action('GetObjectAcl')
GetObjectLegalHold = Action('GetObjectLegalHold')
GetObjectRetention = Action('GetObjectRetention')
GetObjectTagging = Action('GetObjectTagging')
GetObjectTorrent = Action('GetObjectTorrent')
GetObjectVersion = Action('GetObjectVersion')
GetObjectVersionAcl = Action('GetObjectVersionAcl')
GetObjectVersionForReplication = Action('GetObjectVersionForReplication')
GetObjectVersionTagging = Action('GetObjectVersionTagging')
GetObjectVersionTorrent = Action('GetObjectVersionTorrent')
GetReplicationConfiguration = Action('GetReplicationConfiguration')
GetStorageLensConfiguration = Action('GetStorageLensConfiguration')
GetStorageLensConfigurationTagging = \
    Action('GetStorageLensConfigurationTagging')
GetStorageLensDashboard = Action('GetStorageLensDashboard')
HeadBucket = Action('HeadBucket')
ListAccessPoints = Action('ListAccessPoints')
ListAccessPointsForObjectLambda = \
    Action('ListAccessPointsForObjectLambda')
ListAllMyBuckets = Action('ListAllMyBuckets')
ListBucket = Action('ListBucket')
ListBucketByTags = Action('ListBucketByTags')
ListBucketMultipartUploads = Action('ListBucketMultipartUploads')
ListBucketVersions = Action('ListBucketVersions')
ListJobs = Action('ListJobs')
ListMultipartUploadParts = Action('ListMultipartUploadParts')
ListObjects = Action('ListObjects')
ListStorageLensConfigurations = Action('ListStorageLensConfigurations')
ObjectOwnerOverrideToBucketOwner = \
    Action('ObjectOwnerOverrideToBucketOwner')
PutAccelerateConfiguration = Action('PutAccelerateConfiguration')
PutAccessPointConfigurationForObjectLambda = \
    Action('PutAccessPointConfigurationForObjectLambda')
PutAccessPointPolicy = Action('PutAccessPointPolicy')
PutAccessPointPolicyForObjectLambda = \
    Action('PutAccessPointPolicyForObjectLambda')
PutAccountPublicAccessBlock = Action('PutAccountPublicAccessBlock')
PutAnalyticsConfiguration = Action('PutAnalyticsConfiguration')
PutBucketAcl = Action('PutBucketAcl')
PutBucketCORS = Action('PutBucketCORS')
PutBucketLogging = Action('PutBucketLogging')
PutBucketNotification = Action('PutBucketNotification')
PutBucketObjectLockConfiguration = \
    Action('PutBucketObjectLockConfiguration')
PutBucketOwnershipControls = Action('PutBucketOwnershipControls')
PutBucketPolicy = Action('PutBucketPolicy')
PutBucketPublicAccessBlock = Action('PutBucketPublicAccessBlock')
PutBucketRequestPayment = Action('PutBucketRequestPayment')
PutBucketTagging = Action('PutBucketTagging')
PutBucketVersioning = Action('PutBucketVersioning')
PutBucketWebsite = Action('PutBucketWebsite')
PutEncryptionConfiguration = Action('PutEncryptionConfiguration')
PutIntelligentTieringConfiguration = \
    Action('PutIntelligentTieringConfiguration')
PutInventoryConfiguration = Action('PutInventoryConfiguration')
PutIpConfiguration = Action('PutIpConfiguration')
PutJobTagging = Action('PutJobTagging')
PutLifecycleConfiguration = Action('PutLifecycleConfiguration')
PutMetricsConfiguration = Action('PutMetricsConfiguration')
PutObject = Action('PutObject')
PutObjectAcl = Action('PutObjectAcl')
PutObjectLegalHold = Action('PutObjectLegalHold')
PutObjectRetention = Action('PutObjectRetention')
PutObjectTagging = Action('PutObjectTagging')
PutObjectVersionAcl = Action('PutObjectVersionAcl')
PutObjectVersionTagging = Action('PutObjectVersionTagging')
PutReplicationConfiguration = Action('PutReplicationConfiguration')
PutStorageLensConfiguration = Action('PutStorageLensConfiguration')
PutStorageLensConfigurationTagging = \
    Action('PutStorageLensConfigurationTagging')
ReplicateDelete = Action('ReplicateDelete')
ReplicateObject = Action('ReplicateObject')
ReplicateTags = Action('ReplicateTags')
RestoreObject = Action('RestoreObject')
UpdateJobPriority = Action('UpdateJobPriority')
UpdateJobStatus = Action('UpdateJobStatus')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS CodeStar Connections'
prefix = 'codestar-connections'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateConnection = Action('CreateConnection')
CreateHost = Action('CreateHost')
DeleteConnection = Action('DeleteConnection')
DeleteHost = Action('DeleteHost')
GetConnection = Action('GetConnection')
GetHost = Action('GetHost')
GetIndividualAccessToken = Action('GetIndividualAccessToken')
GetInstallationUrl = Action('GetInstallationUrl')
ListConnections = Action('ListConnections')
ListHosts = Action('ListHosts')
ListInstallationTargets = Action('ListInstallationTargets')
ListTagsForResource = Action('ListTagsForResource')
PassConnection = Action('PassConnection')
RegisterAppCode = Action('RegisterAppCode')
StartAppRegistrationHandshake = Action('StartAppRegistrationHandshake')
StartOAuthHandshake = Action('StartOAuthHandshake')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateConnectionInstallation = Action('UpdateConnectionInstallation')
UpdateHost = Action('UpdateHost')
UseConnection = Action('UseConnection')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Fleet Hub for AWS IoT Device Management'
prefix = 'iotfleethub'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApplication = Action('CreateApplication')
CreateDashboard = Action('CreateDashboard')
DeleteApplication = Action('DeleteApplication')
DeleteDashboard = Action('DeleteDashboard')
DescribeApplication = Action('DescribeApplication')
DescribeDashboard = Action('DescribeDashboard')
ListApplications = Action('ListApplications')
ListDashboards = Action('ListDashboards')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateApplication = Action('UpdateApplication')
UpdateDashboard = Action('UpdateDashboard')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'Amazon Location'
prefix = 'geo'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AssociateTrackerConsumer = Action('AssociateTrackerConsumer')
BatchDeleteGeofence = Action('BatchDeleteGeofence')
BatchEvaluateGeofences = Action('BatchEvaluateGeofences')
BatchGetDevicePosition = Action('BatchGetDevicePosition')
BatchPutGeofence = Action('BatchPutGeofence')
BatchUpdateDevicePosition = Action('BatchUpdateDevicePosition')
CreateGeofenceCollection = Action('CreateGeofenceCollection')
CreateMap = Action('CreateMap')
CreatePlaceIndex = Action('CreatePlaceIndex')
CreateTracker = Action('CreateTracker')
DeleteGeofenceCollection = Action('DeleteGeofenceCollection')
DeleteMap = Action('DeleteMap')
DeletePlaceIndex = Action('DeletePlaceIndex')
DeleteTracker = Action('DeleteTracker')
DescribeGeofenceCollection = Action('DescribeGeofenceCollection')
DescribeMap = Action('DescribeMap')
DescribePlaceIndex = Action('DescribePlaceIndex')
DescribeTracker = Action('DescribeTracker')
DisassociateTrackerConsumer = Action('DisassociateTrackerConsumer')
GetDevicePosition = Action('GetDevicePosition')
GetDevicePositionHistory = Action('GetDevicePositionHistory')
GetGeofence = Action('GetGeofence')
GetMapGlyphs = Action('GetMapGlyphs')
GetMapSprites = Action('GetMapSprites')
GetMapStyleDescriptor = Action('GetMapStyleDescriptor')
GetMapTile = Action('GetMapTile')
GetMapTileJson = Action('GetMapTileJson')
ListGeofenceCollections = Action('ListGeofenceCollections')
ListGeofences = Action('ListGeofences')
ListMaps = Action('ListMaps')
ListPlaceIndexes = Action('ListPlaceIndexes')
ListTrackerConsumers = Action('ListTrackerConsumers')
ListTrackers = Action('ListTrackers')
PutGeofence = Action('PutGeofence')
SearchPlaceIndexForPosition = Action('SearchPlaceIndexForPosition')
SearchPlaceIndexForText = Action('SearchPlaceIndexForText')
UpdateGeofenceCollection = Action('UpdateGeofenceCollection')
UpdateTracker = Action('UpdateTracker')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Marketplace'
prefix = 'aws-marketplace'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AcceptAgreementApprovalRequest = Action('AcceptAgreementApprovalRequest')
AssociateProductsWithPrivateMarketplace = \
    Action('AssociateProductsWithPrivateMarketplace')
BatchMeterUsage = Action('BatchMeterUsage')
CancelAgreementRequest = Action('CancelAgreementRequest')
CancelChangeSet = Action('CancelChangeSet')
CompleteTask = Action('CompleteTask')
CreatePrivateMarketplace = Action('CreatePrivateMarketplace')
CreatePrivateMarketplaceProfile = \
    Action('CreatePrivateMarketplaceProfile')
CreatePrivateMarketplaceRequests = \
    Action('CreatePrivateMarketplaceRequests')
DescribeAgreement = Action('DescribeAgreement')
DescribeBuilds = Action('DescribeBuilds')
DescribeChangeSet = Action('DescribeChangeSet')
DescribeEntity = Action('DescribeEntity')
DescribePrivateMarketplaceProducts = \
    Action('DescribePrivateMarketplaceProducts')
DescribePrivateMarketplaceProfile = \
    Action('DescribePrivateMarketplaceProfile')
DescribePrivateMarketplaceRequests = \
    Action('DescribePrivateMarketplaceRequests')
DescribePrivateMarketplaceSettings = \
    Action('DescribePrivateMarketplaceSettings')
DescribePrivateMarketplaceStatus = \
    Action('DescribePrivateMarketplaceStatus')
DescribeProcurementSystemConfiguration = \
    Action('DescribeProcurementSystemConfiguration')
DescribeTask = Action('DescribeTask')
DisassociateProductsFromPrivateMarketplace = \
    Action('DisassociateProductsFromPrivateMarketplace')
GetAgreementApprovalRequest = Action('GetAgreementApprovalRequest')
GetAgreementRequest = Action('GetAgreementRequest')
GetAgreementTerms = Action('GetAgreementTerms')
GetEntitlements = Action('GetEntitlements')
ListAgreementApprovalRequests = Action('ListAgreementApprovalRequests')
ListAgreementRequests = Action('ListAgreementRequests')
ListBuilds = Action('ListBuilds')
ListChangeSets = Action('ListChangeSets')
ListEntities = Action('ListEntities')
ListPrivateMarketplaceProducts = Action('ListPrivateMarketplaceProducts')
ListPrivateMarketplaceRequests = Action('ListPrivateMarketplaceRequests')
ListTasks = Action('ListTasks')
MeterUsage = Action('MeterUsage')
PutProcurementSystemConfiguration = \
    Action('PutProcurementSystemConfiguration')
RegisterUsage = Action('RegisterUsage')
RejectAgreementApprovalRequest = Action('RejectAgreementApprovalRequest')
ResolveCustomer = Action('ResolveCustomer')
SearchAgreements = Action('SearchAgreements')
StartBuild = Action('StartBuild')
StartChangeSet = Action('StartChangeSet')
StartPrivateMarketplace = Action('StartPrivateMarketplace')
StopPrivateMarketplace = Action('StopPrivateMarketplace')
Subscribe = Action('Subscribe')
Unsubscribe = Action('Unsubscribe')
UpdateAgreementApprovalRequest = Action('UpdateAgreementApprovalRequest')
UpdatePrivateMarketplaceProfile = \
    Action('UpdatePrivateMarketplaceProfile')
UpdatePrivateMarketplaceSettings = \
    Action('UpdatePrivateMarketplaceSettings')
UpdateTask = Action('UpdateTask')
ViewSubscriptions = Action('ViewSubscriptions')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Panorama'
prefix = 'panorama'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


CreateApp = Action('CreateApp')
CreateAppDeployment = Action('CreateAppDeployment')
CreateAppVersion = Action('CreateAppVersion')
CreateDataSource = Action('CreateDataSource')
CreateDeploymentConfiguration = Action('CreateDeploymentConfiguration')
CreateDevice = Action('CreateDevice')
CreateDeviceUpdate = Action('CreateDeviceUpdate')
CreateInputs = Action('CreateInputs')
CreateModel = Action('CreateModel')
CreateStreams = Action('CreateStreams')
DeleteApp = Action('DeleteApp')
DeleteAppVersion = Action('DeleteAppVersion')
DeleteDataSource = Action('DeleteDataSource')
DeleteDevice = Action('DeleteDevice')
DeleteModel = Action('DeleteModel')
DescribeApp = Action('DescribeApp')
DescribeAppDeployment = Action('DescribeAppDeployment')
DescribeAppVersion = Action('DescribeAppVersion')
DescribeDataSource = Action('DescribeDataSource')
DescribeDevice = Action('DescribeDevice')
DescribeDeviceUpdate = Action('DescribeDeviceUpdate')
DescribeModel = Action('DescribeModel')
DescribeSoftware = Action('DescribeSoftware')
GetDeploymentConfiguration = Action('GetDeploymentConfiguration')
GetInputs = Action('GetInputs')
GetStreams = Action('GetStreams')
GetWebSocketURL = Action('GetWebSocketURL')
ListAppDeploymentOperations = Action('ListAppDeploymentOperations')
ListAppVersions = Action('ListAppVersions')
ListApps = Action('ListApps')
ListDataSources = Action('ListDataSources')
ListDeploymentConfigurations = Action('ListDeploymentConfigurations')
ListDeviceUpdates = Action('ListDeviceUpdates')
ListDevices = Action('ListDevices')
ListModels = Action('ListModels')
ListTagsForResource = Action('ListTagsForResource')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateApp = Action('UpdateApp')
UpdateAppConfiguration = Action('UpdateAppConfiguration')
UpdateDataSource = Action('UpdateDataSource')
UpdateDevice = Action('UpdateDevice')



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from aws import Action as BaseAction
from aws import BaseARN

service_name = 'AWS Global Accelerator'
prefix = 'globalaccelerator'


class Action(BaseAction):
    def __init__(self, action=None):
        sup = super(Action, self)
        sup.__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource='', region='', account=''):
        sup = super(ARN, self)
        sup.__init__(service=prefix, resource=resource, region=region,
                     account=account)


AddCustomRoutingEndpoints = Action('AddCustomRoutingEndpoints')
AdvertiseByoipCidr = Action('AdvertiseByoipCidr')
AllowCustomRoutingTraffic = Action('AllowCustomRoutingTraffic')
CreateAccelerator = Action('CreateAccelerator')
CreateCustomRoutingAccelerator = Action('CreateCustomRoutingAccelerator')
CreateCustomRoutingEndpointGroup = \
    Action('CreateCustomRoutingEndpointGroup')
CreateCustomRoutingListener = Action('CreateCustomRoutingListener')
CreateEndpointGroup = Action('CreateEndpointGroup')
CreateListener = Action('CreateListener')
DeleteAccelerator = Action('DeleteAccelerator')
DeleteCustomRoutingAccelerator = Action('DeleteCustomRoutingAccelerator')
DeleteCustomRoutingEndpointGroup = \
    Action('DeleteCustomRoutingEndpointGroup')
DeleteCustomRoutingListener = Action('DeleteCustomRoutingListener')
DeleteEndpointGroup = Action('DeleteEndpointGroup')
DeleteListener = Action('DeleteListener')
DenyCustomRoutingTraffic = Action('DenyCustomRoutingTraffic')
DeprovisionByoipCidr = Action('DeprovisionByoipCidr')
DescribeAccelerator = Action('DescribeAccelerator')
DescribeAcceleratorAttributes = Action('DescribeAcceleratorAttributes')
DescribeCustomRoutingAccelerator = \
    Action('DescribeCustomRoutingAccelerator')
DescribeCustomRoutingAcceleratorAttributes = \
    Action('DescribeCustomRoutingAcceleratorAttributes')
DescribeCustomRoutingEndpointGroup = \
    Action('DescribeCustomRoutingEndpointGroup')
DescribeCustomRoutingListener = Action('DescribeCustomRoutingListener')
DescribeEndpointGroup = Action('DescribeEndpointGroup')
DescribeListener = Action('DescribeListener')
ListAccelerators = Action('ListAccelerators')
ListByoipCidrs = Action('ListByoipCidrs')
ListCustomRoutingAccelerators = Action('ListCustomRoutingAccelerators')
ListCustomRoutingEndpointGroups = \
    Action('ListCustomRoutingEndpointGroups')
ListCustomRoutingListeners = Action('ListCustomRoutingListeners')
ListCustomRoutingPortMappings = Action('ListCustomRoutingPortMappings')
ListCustomRoutingPortMappingsByDestination = \
    Action('ListCustomRoutingPortMappingsByDestination')
ListEndpointGroups = Action('ListEndpointGroups')
ListListeners = Action('ListListeners')
ListTagsForResource = Action('ListTagsForResource')
ProvisionByoipCidr = Action('ProvisionByoipCidr')
RemoveCustomRoutingEndpoints = Action('RemoveCustomRoutingEndpoints')
TagResource = Action('TagResource')
UntagResource = Action('UntagResource')
UpdateAccelerator = Action('UpdateAccelerator')
UpdateAcceleratorAttributes = Action('UpdateAcceleratorAttributes')
UpdateCustomRoutingAccelerator = Action('UpdateCustomRoutingAccelerator')
UpdateCustomRoutingAcceleratorAttributes = \
    Action('UpdateCustomRoutingAcceleratorAttributes')
UpdateCustomRoutingListener = Action('UpdateCustomRoutingListener')
UpdateEndpointGroup = Action('UpdateEndpointGroup')
UpdateListener = Action('UpdateListener')
WithdrawByoipCidr = Action('WithdrawByoipCidr')
